# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TsoaPartialTunnelObject_(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "tunnel_id": "float",
        "server_src_id": "float",
        "server_dst_id": "float",
        "interface_src_id": "float",
        "tunnel_cidr_ipv6": "str",
        "tunnel_status": "Status",
        "tunnel_status_reason": "str",
    }

    attribute_map = {
        "tunnel_id": "tunnel_id",
        "server_src_id": "server_src_id",
        "server_dst_id": "server_dst_id",
        "interface_src_id": "interface_src_id",
        "tunnel_cidr_ipv6": "tunnel_cidr_ipv6",
        "tunnel_status": "tunnel_status",
        "tunnel_status_reason": "tunnel_status_reason",
    }

    def __init__(
        self,
        tunnel_id=None,
        server_src_id=None,
        server_dst_id=None,
        interface_src_id=None,
        tunnel_cidr_ipv6=None,
        tunnel_status=None,
        tunnel_status_reason=None,
    ):  # noqa: E501
        """TsoaPartialTunnelObject_ - a model defined in Swagger"""  # noqa: E501
        self._tunnel_id = None
        self._server_src_id = None
        self._server_dst_id = None
        self._interface_src_id = None
        self._tunnel_cidr_ipv6 = None
        self._tunnel_status = None
        self._tunnel_status_reason = None
        self.discriminator = None
        if tunnel_id is not None:
            self.tunnel_id = tunnel_id
        if server_src_id is not None:
            self.server_src_id = server_src_id
        if server_dst_id is not None:
            self.server_dst_id = server_dst_id
        if interface_src_id is not None:
            self.interface_src_id = interface_src_id
        if tunnel_cidr_ipv6 is not None:
            self.tunnel_cidr_ipv6 = tunnel_cidr_ipv6
        if tunnel_status is not None:
            self.tunnel_status = tunnel_status
        if tunnel_status_reason is not None:
            self.tunnel_status_reason = tunnel_status_reason

    @property
    def tunnel_id(self):
        """Gets the tunnel_id of this TsoaPartialTunnelObject_.  # noqa: E501


        :return: The tunnel_id of this TsoaPartialTunnelObject_.  # noqa: E501
        :rtype: float
        """
        return self._tunnel_id

    @tunnel_id.setter
    def tunnel_id(self, tunnel_id):
        """Sets the tunnel_id of this TsoaPartialTunnelObject_.


        :param tunnel_id: The tunnel_id of this TsoaPartialTunnelObject_.  # noqa: E501
        :type: float
        """

        self._tunnel_id = tunnel_id

    @property
    def server_src_id(self):
        """Gets the server_src_id of this TsoaPartialTunnelObject_.  # noqa: E501


        :return: The server_src_id of this TsoaPartialTunnelObject_.  # noqa: E501
        :rtype: float
        """
        return self._server_src_id

    @server_src_id.setter
    def server_src_id(self, server_src_id):
        """Sets the server_src_id of this TsoaPartialTunnelObject_.


        :param server_src_id: The server_src_id of this TsoaPartialTunnelObject_.  # noqa: E501
        :type: float
        """

        self._server_src_id = server_src_id

    @property
    def server_dst_id(self):
        """Gets the server_dst_id of this TsoaPartialTunnelObject_.  # noqa: E501


        :return: The server_dst_id of this TsoaPartialTunnelObject_.  # noqa: E501
        :rtype: float
        """
        return self._server_dst_id

    @server_dst_id.setter
    def server_dst_id(self, server_dst_id):
        """Sets the server_dst_id of this TsoaPartialTunnelObject_.


        :param server_dst_id: The server_dst_id of this TsoaPartialTunnelObject_.  # noqa: E501
        :type: float
        """

        self._server_dst_id = server_dst_id

    @property
    def interface_src_id(self):
        """Gets the interface_src_id of this TsoaPartialTunnelObject_.  # noqa: E501


        :return: The interface_src_id of this TsoaPartialTunnelObject_.  # noqa: E501
        :rtype: float
        """
        return self._interface_src_id

    @interface_src_id.setter
    def interface_src_id(self, interface_src_id):
        """Sets the interface_src_id of this TsoaPartialTunnelObject_.


        :param interface_src_id: The interface_src_id of this TsoaPartialTunnelObject_.  # noqa: E501
        :type: float
        """

        self._interface_src_id = interface_src_id

    @property
    def tunnel_cidr_ipv6(self):
        """Gets the tunnel_cidr_ipv6 of this TsoaPartialTunnelObject_.  # noqa: E501


        :return: The tunnel_cidr_ipv6 of this TsoaPartialTunnelObject_.  # noqa: E501
        :rtype: str
        """
        return self._tunnel_cidr_ipv6

    @tunnel_cidr_ipv6.setter
    def tunnel_cidr_ipv6(self, tunnel_cidr_ipv6):
        """Sets the tunnel_cidr_ipv6 of this TsoaPartialTunnelObject_.


        :param tunnel_cidr_ipv6: The tunnel_cidr_ipv6 of this TsoaPartialTunnelObject_.  # noqa: E501
        :type: str
        """

        self._tunnel_cidr_ipv6 = tunnel_cidr_ipv6

    @property
    def tunnel_status(self):
        """Gets the tunnel_status of this TsoaPartialTunnelObject_.  # noqa: E501


        :return: The tunnel_status of this TsoaPartialTunnelObject_.  # noqa: E501
        :rtype: Status
        """
        return self._tunnel_status

    @tunnel_status.setter
    def tunnel_status(self, tunnel_status):
        """Sets the tunnel_status of this TsoaPartialTunnelObject_.


        :param tunnel_status: The tunnel_status of this TsoaPartialTunnelObject_.  # noqa: E501
        :type: Status
        """

        self._tunnel_status = tunnel_status

    @property
    def tunnel_status_reason(self):
        """Gets the tunnel_status_reason of this TsoaPartialTunnelObject_.  # noqa: E501


        :return: The tunnel_status_reason of this TsoaPartialTunnelObject_.  # noqa: E501
        :rtype: str
        """
        return self._tunnel_status_reason

    @tunnel_status_reason.setter
    def tunnel_status_reason(self, tunnel_status_reason):
        """Sets the tunnel_status_reason of this TsoaPartialTunnelObject_.


        :param tunnel_status_reason: The tunnel_status_reason of this TsoaPartialTunnelObject_.  # noqa: E501
        :type: str
        """

        self._tunnel_status_reason = tunnel_status_reason

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(TsoaPartialTunnelObject_, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TsoaPartialTunnelObject_):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TsoaPartialAgentObject_(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "agent_services_default_status": "bool",
        "api_key_id": "float",
        "agent_public_ipv4": "str",
        "agent_location_lat": "float",
        "agent_location_lon": "float",
        "agent_location_city": "str",
        "agent_location_country": "str",
        "agent_device_id": "str",
        "agent_name": "str",
        "agent_status": "PlatformAgentStatus",
        "agent_version": "str",
        "agent_provider_id": "float",
        "agent_is_online": "bool",
        "agent_locked_fields": "AgentLockedFields",
        "agent_modified_at": "datetime",
        "agent_is_virtual": "bool",
        "agent_type": "PlatformAgentTypeLocal",
    }

    attribute_map = {
        "agent_services_default_status": "agent_services_default_status",
        "api_key_id": "api_key_id",
        "agent_public_ipv4": "agent_public_ipv4",
        "agent_location_lat": "agent_location_lat",
        "agent_location_lon": "agent_location_lon",
        "agent_location_city": "agent_location_city",
        "agent_location_country": "agent_location_country",
        "agent_device_id": "agent_device_id",
        "agent_name": "agent_name",
        "agent_status": "agent_status",
        "agent_version": "agent_version",
        "agent_provider_id": "agent_provider_id",
        "agent_is_online": "agent_is_online",
        "agent_locked_fields": "agent_locked_fields",
        "agent_modified_at": "agent_modified_at",
        "agent_is_virtual": "agent_is_virtual",
        "agent_type": "agent_type",
    }

    def __init__(
        self,
        agent_services_default_status=None,
        api_key_id=None,
        agent_public_ipv4=None,
        agent_location_lat=None,
        agent_location_lon=None,
        agent_location_city=None,
        agent_location_country=None,
        agent_device_id=None,
        agent_name=None,
        agent_status=None,
        agent_version=None,
        agent_provider_id=None,
        agent_is_online=None,
        agent_locked_fields=None,
        agent_modified_at=None,
        agent_is_virtual=None,
        agent_type=None,
    ):  # noqa: E501
        """TsoaPartialAgentObject_ - a model defined in Swagger"""  # noqa: E501
        self._agent_services_default_status = None
        self._api_key_id = None
        self._agent_public_ipv4 = None
        self._agent_location_lat = None
        self._agent_location_lon = None
        self._agent_location_city = None
        self._agent_location_country = None
        self._agent_device_id = None
        self._agent_name = None
        self._agent_status = None
        self._agent_version = None
        self._agent_provider_id = None
        self._agent_is_online = None
        self._agent_locked_fields = None
        self._agent_modified_at = None
        self._agent_is_virtual = None
        self._agent_type = None
        self.discriminator = None
        if agent_services_default_status is not None:
            self.agent_services_default_status = agent_services_default_status
        if api_key_id is not None:
            self.api_key_id = api_key_id
        if agent_public_ipv4 is not None:
            self.agent_public_ipv4 = agent_public_ipv4
        if agent_location_lat is not None:
            self.agent_location_lat = agent_location_lat
        if agent_location_lon is not None:
            self.agent_location_lon = agent_location_lon
        if agent_location_city is not None:
            self.agent_location_city = agent_location_city
        if agent_location_country is not None:
            self.agent_location_country = agent_location_country
        if agent_device_id is not None:
            self.agent_device_id = agent_device_id
        if agent_name is not None:
            self.agent_name = agent_name
        if agent_status is not None:
            self.agent_status = agent_status
        if agent_version is not None:
            self.agent_version = agent_version
        if agent_provider_id is not None:
            self.agent_provider_id = agent_provider_id
        if agent_is_online is not None:
            self.agent_is_online = agent_is_online
        if agent_locked_fields is not None:
            self.agent_locked_fields = agent_locked_fields
        if agent_modified_at is not None:
            self.agent_modified_at = agent_modified_at
        if agent_is_virtual is not None:
            self.agent_is_virtual = agent_is_virtual
        if agent_type is not None:
            self.agent_type = agent_type

    @property
    def agent_services_default_status(self):
        """Gets the agent_services_default_status of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_services_default_status of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: bool
        """
        return self._agent_services_default_status

    @agent_services_default_status.setter
    def agent_services_default_status(self, agent_services_default_status):
        """Sets the agent_services_default_status of this TsoaPartialAgentObject_.


        :param agent_services_default_status: The agent_services_default_status of this TsoaPartialAgentObject_.  # noqa: E501
        :type: bool
        """

        self._agent_services_default_status = agent_services_default_status

    @property
    def api_key_id(self):
        """Gets the api_key_id of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The api_key_id of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: float
        """
        return self._api_key_id

    @api_key_id.setter
    def api_key_id(self, api_key_id):
        """Sets the api_key_id of this TsoaPartialAgentObject_.


        :param api_key_id: The api_key_id of this TsoaPartialAgentObject_.  # noqa: E501
        :type: float
        """

        self._api_key_id = api_key_id

    @property
    def agent_public_ipv4(self):
        """Gets the agent_public_ipv4 of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_public_ipv4 of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: str
        """
        return self._agent_public_ipv4

    @agent_public_ipv4.setter
    def agent_public_ipv4(self, agent_public_ipv4):
        """Sets the agent_public_ipv4 of this TsoaPartialAgentObject_.


        :param agent_public_ipv4: The agent_public_ipv4 of this TsoaPartialAgentObject_.  # noqa: E501
        :type: str
        """

        self._agent_public_ipv4 = agent_public_ipv4

    @property
    def agent_location_lat(self):
        """Gets the agent_location_lat of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_location_lat of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: float
        """
        return self._agent_location_lat

    @agent_location_lat.setter
    def agent_location_lat(self, agent_location_lat):
        """Sets the agent_location_lat of this TsoaPartialAgentObject_.


        :param agent_location_lat: The agent_location_lat of this TsoaPartialAgentObject_.  # noqa: E501
        :type: float
        """

        self._agent_location_lat = agent_location_lat

    @property
    def agent_location_lon(self):
        """Gets the agent_location_lon of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_location_lon of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: float
        """
        return self._agent_location_lon

    @agent_location_lon.setter
    def agent_location_lon(self, agent_location_lon):
        """Sets the agent_location_lon of this TsoaPartialAgentObject_.


        :param agent_location_lon: The agent_location_lon of this TsoaPartialAgentObject_.  # noqa: E501
        :type: float
        """

        self._agent_location_lon = agent_location_lon

    @property
    def agent_location_city(self):
        """Gets the agent_location_city of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_location_city of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: str
        """
        return self._agent_location_city

    @agent_location_city.setter
    def agent_location_city(self, agent_location_city):
        """Sets the agent_location_city of this TsoaPartialAgentObject_.


        :param agent_location_city: The agent_location_city of this TsoaPartialAgentObject_.  # noqa: E501
        :type: str
        """

        self._agent_location_city = agent_location_city

    @property
    def agent_location_country(self):
        """Gets the agent_location_country of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_location_country of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: str
        """
        return self._agent_location_country

    @agent_location_country.setter
    def agent_location_country(self, agent_location_country):
        """Sets the agent_location_country of this TsoaPartialAgentObject_.


        :param agent_location_country: The agent_location_country of this TsoaPartialAgentObject_.  # noqa: E501
        :type: str
        """

        self._agent_location_country = agent_location_country

    @property
    def agent_device_id(self):
        """Gets the agent_device_id of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_device_id of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: str
        """
        return self._agent_device_id

    @agent_device_id.setter
    def agent_device_id(self, agent_device_id):
        """Sets the agent_device_id of this TsoaPartialAgentObject_.


        :param agent_device_id: The agent_device_id of this TsoaPartialAgentObject_.  # noqa: E501
        :type: str
        """

        self._agent_device_id = agent_device_id

    @property
    def agent_name(self):
        """Gets the agent_name of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_name of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: str
        """
        return self._agent_name

    @agent_name.setter
    def agent_name(self, agent_name):
        """Sets the agent_name of this TsoaPartialAgentObject_.


        :param agent_name: The agent_name of this TsoaPartialAgentObject_.  # noqa: E501
        :type: str
        """

        self._agent_name = agent_name

    @property
    def agent_status(self):
        """Gets the agent_status of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_status of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: PlatformAgentStatus
        """
        return self._agent_status

    @agent_status.setter
    def agent_status(self, agent_status):
        """Sets the agent_status of this TsoaPartialAgentObject_.


        :param agent_status: The agent_status of this TsoaPartialAgentObject_.  # noqa: E501
        :type: PlatformAgentStatus
        """

        self._agent_status = agent_status

    @property
    def agent_version(self):
        """Gets the agent_version of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_version of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: str
        """
        return self._agent_version

    @agent_version.setter
    def agent_version(self, agent_version):
        """Sets the agent_version of this TsoaPartialAgentObject_.


        :param agent_version: The agent_version of this TsoaPartialAgentObject_.  # noqa: E501
        :type: str
        """

        self._agent_version = agent_version

    @property
    def agent_provider_id(self):
        """Gets the agent_provider_id of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_provider_id of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: float
        """
        return self._agent_provider_id

    @agent_provider_id.setter
    def agent_provider_id(self, agent_provider_id):
        """Sets the agent_provider_id of this TsoaPartialAgentObject_.


        :param agent_provider_id: The agent_provider_id of this TsoaPartialAgentObject_.  # noqa: E501
        :type: float
        """

        self._agent_provider_id = agent_provider_id

    @property
    def agent_is_online(self):
        """Gets the agent_is_online of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_is_online of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: bool
        """
        return self._agent_is_online

    @agent_is_online.setter
    def agent_is_online(self, agent_is_online):
        """Sets the agent_is_online of this TsoaPartialAgentObject_.


        :param agent_is_online: The agent_is_online of this TsoaPartialAgentObject_.  # noqa: E501
        :type: bool
        """

        self._agent_is_online = agent_is_online

    @property
    def agent_locked_fields(self):
        """Gets the agent_locked_fields of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_locked_fields of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: AgentLockedFields
        """
        return self._agent_locked_fields

    @agent_locked_fields.setter
    def agent_locked_fields(self, agent_locked_fields):
        """Sets the agent_locked_fields of this TsoaPartialAgentObject_.


        :param agent_locked_fields: The agent_locked_fields of this TsoaPartialAgentObject_.  # noqa: E501
        :type: AgentLockedFields
        """

        self._agent_locked_fields = agent_locked_fields

    @property
    def agent_modified_at(self):
        """Gets the agent_modified_at of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_modified_at of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: datetime
        """
        return self._agent_modified_at

    @agent_modified_at.setter
    def agent_modified_at(self, agent_modified_at):
        """Sets the agent_modified_at of this TsoaPartialAgentObject_.


        :param agent_modified_at: The agent_modified_at of this TsoaPartialAgentObject_.  # noqa: E501
        :type: datetime
        """

        self._agent_modified_at = agent_modified_at

    @property
    def agent_is_virtual(self):
        """Gets the agent_is_virtual of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_is_virtual of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: bool
        """
        return self._agent_is_virtual

    @agent_is_virtual.setter
    def agent_is_virtual(self, agent_is_virtual):
        """Sets the agent_is_virtual of this TsoaPartialAgentObject_.


        :param agent_is_virtual: The agent_is_virtual of this TsoaPartialAgentObject_.  # noqa: E501
        :type: bool
        """

        self._agent_is_virtual = agent_is_virtual

    @property
    def agent_type(self):
        """Gets the agent_type of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_type of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: PlatformAgentTypeLocal
        """
        return self._agent_type

    @agent_type.setter
    def agent_type(self, agent_type):
        """Sets the agent_type of this TsoaPartialAgentObject_.


        :param agent_type: The agent_type of this TsoaPartialAgentObject_.  # noqa: E501
        :type: PlatformAgentTypeLocal
        """

        self._agent_type = agent_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(TsoaPartialAgentObject_, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TsoaPartialAgentObject_):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ChangePathObjectDataCosts(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "price": "float",
        "latency": "float",
        "jitter": "float",
        "bandwidth": "float",
    }

    attribute_map = {
        "price": "price",
        "latency": "latency",
        "jitter": "jitter",
        "bandwidth": "bandwidth",
    }

    def __init__(
        self, price=None, latency=None, jitter=None, bandwidth=None
    ):  # noqa: E501
        """ChangePathObjectDataCosts - a model defined in Swagger"""  # noqa: E501
        self._price = None
        self._latency = None
        self._jitter = None
        self._bandwidth = None
        self.discriminator = None
        if price is not None:
            self.price = price
        if latency is not None:
            self.latency = latency
        if jitter is not None:
            self.jitter = jitter
        if bandwidth is not None:
            self.bandwidth = bandwidth

    @property
    def price(self):
        """Gets the price of this ChangePathObjectDataCosts.  # noqa: E501


        :return: The price of this ChangePathObjectDataCosts.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this ChangePathObjectDataCosts.


        :param price: The price of this ChangePathObjectDataCosts.  # noqa: E501
        :type: float
        """

        self._price = price

    @property
    def latency(self):
        """Gets the latency of this ChangePathObjectDataCosts.  # noqa: E501


        :return: The latency of this ChangePathObjectDataCosts.  # noqa: E501
        :rtype: float
        """
        return self._latency

    @latency.setter
    def latency(self, latency):
        """Sets the latency of this ChangePathObjectDataCosts.


        :param latency: The latency of this ChangePathObjectDataCosts.  # noqa: E501
        :type: float
        """

        self._latency = latency

    @property
    def jitter(self):
        """Gets the jitter of this ChangePathObjectDataCosts.  # noqa: E501


        :return: The jitter of this ChangePathObjectDataCosts.  # noqa: E501
        :rtype: float
        """
        return self._jitter

    @jitter.setter
    def jitter(self, jitter):
        """Sets the jitter of this ChangePathObjectDataCosts.


        :param jitter: The jitter of this ChangePathObjectDataCosts.  # noqa: E501
        :type: float
        """

        self._jitter = jitter

    @property
    def bandwidth(self):
        """Gets the bandwidth of this ChangePathObjectDataCosts.  # noqa: E501


        :return: The bandwidth of this ChangePathObjectDataCosts.  # noqa: E501
        :rtype: float
        """
        return self._bandwidth

    @bandwidth.setter
    def bandwidth(self, bandwidth):
        """Sets the bandwidth of this ChangePathObjectDataCosts.


        :param bandwidth: The bandwidth of this ChangePathObjectDataCosts.  # noqa: E501
        :type: float
        """

        self._bandwidth = bandwidth

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(ChangePathObjectDataCosts, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChangePathObjectDataCosts):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TsoaPartialUserSrObject_(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "user_id": "float",
        "region_id": "float",
        "user_sr_location_lat": "float",
        "user_sr_location_lon": "float",
        "user_sr_location_city": "str",
        "color_id": "float",
        "bandwidth_min": "float",
        "jitter_max": "float",
        "latency_max": "float",
        "price_max": "float",
        "user_ipv4_source_addr": "str",
        "user_ipv6_source_addr": "str",
        "user_ipv4_dest_addr": "str",
        "user_ipv6_dest_addr": "str",
        "user_ipv4_dest_cidr": "str",
        "user_ipv6_dest_cidr": "str",
        "server_vpn_id": "float",
        "server_vin_id": "float",
        "server_ven_id": "float",
        "sr_policy_id": "float",
        "user_sr_direction": "UserSrDirection",
        "user_sr_status": "Status",
        "user_sr_status_reason": "str",
        "user_sr_is_via_sdn": "bool",
    }

    attribute_map = {
        "user_id": "user_id",
        "region_id": "region_id",
        "user_sr_location_lat": "user_sr_location_lat",
        "user_sr_location_lon": "user_sr_location_lon",
        "user_sr_location_city": "user_sr_location_city",
        "color_id": "color_id",
        "bandwidth_min": "bandwidth_min",
        "jitter_max": "jitter_max",
        "latency_max": "latency_max",
        "price_max": "price_max",
        "user_ipv4_source_addr": "user_ipv4_source_addr",
        "user_ipv6_source_addr": "user_ipv6_source_addr",
        "user_ipv4_dest_addr": "user_ipv4_dest_addr",
        "user_ipv6_dest_addr": "user_ipv6_dest_addr",
        "user_ipv4_dest_cidr": "user_ipv4_dest_cidr",
        "user_ipv6_dest_cidr": "user_ipv6_dest_cidr",
        "server_vpn_id": "server_vpn_id",
        "server_vin_id": "server_vin_id",
        "server_ven_id": "server_ven_id",
        "sr_policy_id": "sr_policy_id",
        "user_sr_direction": "user_sr_direction",
        "user_sr_status": "user_sr_status",
        "user_sr_status_reason": "user_sr_status_reason",
        "user_sr_is_via_sdn": "user_sr_is_via_sdn",
    }

    def __init__(
        self,
        user_id=None,
        region_id=None,
        user_sr_location_lat=None,
        user_sr_location_lon=None,
        user_sr_location_city=None,
        color_id=None,
        bandwidth_min=None,
        jitter_max=None,
        latency_max=None,
        price_max=None,
        user_ipv4_source_addr=None,
        user_ipv6_source_addr=None,
        user_ipv4_dest_addr=None,
        user_ipv6_dest_addr=None,
        user_ipv4_dest_cidr=None,
        user_ipv6_dest_cidr=None,
        server_vpn_id=None,
        server_vin_id=None,
        server_ven_id=None,
        sr_policy_id=None,
        user_sr_direction=None,
        user_sr_status=None,
        user_sr_status_reason=None,
        user_sr_is_via_sdn=None,
    ):  # noqa: E501
        """TsoaPartialUserSrObject_ - a model defined in Swagger"""  # noqa: E501
        self._user_id = None
        self._region_id = None
        self._user_sr_location_lat = None
        self._user_sr_location_lon = None
        self._user_sr_location_city = None
        self._color_id = None
        self._bandwidth_min = None
        self._jitter_max = None
        self._latency_max = None
        self._price_max = None
        self._user_ipv4_source_addr = None
        self._user_ipv6_source_addr = None
        self._user_ipv4_dest_addr = None
        self._user_ipv6_dest_addr = None
        self._user_ipv4_dest_cidr = None
        self._user_ipv6_dest_cidr = None
        self._server_vpn_id = None
        self._server_vin_id = None
        self._server_ven_id = None
        self._sr_policy_id = None
        self._user_sr_direction = None
        self._user_sr_status = None
        self._user_sr_status_reason = None
        self._user_sr_is_via_sdn = None
        self.discriminator = None
        if user_id is not None:
            self.user_id = user_id
        if region_id is not None:
            self.region_id = region_id
        if user_sr_location_lat is not None:
            self.user_sr_location_lat = user_sr_location_lat
        if user_sr_location_lon is not None:
            self.user_sr_location_lon = user_sr_location_lon
        if user_sr_location_city is not None:
            self.user_sr_location_city = user_sr_location_city
        if color_id is not None:
            self.color_id = color_id
        if bandwidth_min is not None:
            self.bandwidth_min = bandwidth_min
        if jitter_max is not None:
            self.jitter_max = jitter_max
        if latency_max is not None:
            self.latency_max = latency_max
        if price_max is not None:
            self.price_max = price_max
        if user_ipv4_source_addr is not None:
            self.user_ipv4_source_addr = user_ipv4_source_addr
        if user_ipv6_source_addr is not None:
            self.user_ipv6_source_addr = user_ipv6_source_addr
        if user_ipv4_dest_addr is not None:
            self.user_ipv4_dest_addr = user_ipv4_dest_addr
        if user_ipv6_dest_addr is not None:
            self.user_ipv6_dest_addr = user_ipv6_dest_addr
        if user_ipv4_dest_cidr is not None:
            self.user_ipv4_dest_cidr = user_ipv4_dest_cidr
        if user_ipv6_dest_cidr is not None:
            self.user_ipv6_dest_cidr = user_ipv6_dest_cidr
        if server_vpn_id is not None:
            self.server_vpn_id = server_vpn_id
        if server_vin_id is not None:
            self.server_vin_id = server_vin_id
        if server_ven_id is not None:
            self.server_ven_id = server_ven_id
        if sr_policy_id is not None:
            self.sr_policy_id = sr_policy_id
        if user_sr_direction is not None:
            self.user_sr_direction = user_sr_direction
        if user_sr_status is not None:
            self.user_sr_status = user_sr_status
        if user_sr_status_reason is not None:
            self.user_sr_status_reason = user_sr_status_reason
        if user_sr_is_via_sdn is not None:
            self.user_sr_is_via_sdn = user_sr_is_via_sdn

    @property
    def user_id(self):
        """Gets the user_id of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The user_id of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: float
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this TsoaPartialUserSrObject_.


        :param user_id: The user_id of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: float
        """

        self._user_id = user_id

    @property
    def region_id(self):
        """Gets the region_id of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The region_id of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: float
        """
        return self._region_id

    @region_id.setter
    def region_id(self, region_id):
        """Sets the region_id of this TsoaPartialUserSrObject_.


        :param region_id: The region_id of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: float
        """

        self._region_id = region_id

    @property
    def user_sr_location_lat(self):
        """Gets the user_sr_location_lat of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The user_sr_location_lat of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: float
        """
        return self._user_sr_location_lat

    @user_sr_location_lat.setter
    def user_sr_location_lat(self, user_sr_location_lat):
        """Sets the user_sr_location_lat of this TsoaPartialUserSrObject_.


        :param user_sr_location_lat: The user_sr_location_lat of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: float
        """

        self._user_sr_location_lat = user_sr_location_lat

    @property
    def user_sr_location_lon(self):
        """Gets the user_sr_location_lon of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The user_sr_location_lon of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: float
        """
        return self._user_sr_location_lon

    @user_sr_location_lon.setter
    def user_sr_location_lon(self, user_sr_location_lon):
        """Sets the user_sr_location_lon of this TsoaPartialUserSrObject_.


        :param user_sr_location_lon: The user_sr_location_lon of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: float
        """

        self._user_sr_location_lon = user_sr_location_lon

    @property
    def user_sr_location_city(self):
        """Gets the user_sr_location_city of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The user_sr_location_city of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: str
        """
        return self._user_sr_location_city

    @user_sr_location_city.setter
    def user_sr_location_city(self, user_sr_location_city):
        """Sets the user_sr_location_city of this TsoaPartialUserSrObject_.


        :param user_sr_location_city: The user_sr_location_city of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: str
        """

        self._user_sr_location_city = user_sr_location_city

    @property
    def color_id(self):
        """Gets the color_id of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The color_id of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: float
        """
        return self._color_id

    @color_id.setter
    def color_id(self, color_id):
        """Sets the color_id of this TsoaPartialUserSrObject_.


        :param color_id: The color_id of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: float
        """

        self._color_id = color_id

    @property
    def bandwidth_min(self):
        """Gets the bandwidth_min of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The bandwidth_min of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: float
        """
        return self._bandwidth_min

    @bandwidth_min.setter
    def bandwidth_min(self, bandwidth_min):
        """Sets the bandwidth_min of this TsoaPartialUserSrObject_.


        :param bandwidth_min: The bandwidth_min of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: float
        """

        self._bandwidth_min = bandwidth_min

    @property
    def jitter_max(self):
        """Gets the jitter_max of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The jitter_max of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: float
        """
        return self._jitter_max

    @jitter_max.setter
    def jitter_max(self, jitter_max):
        """Sets the jitter_max of this TsoaPartialUserSrObject_.


        :param jitter_max: The jitter_max of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: float
        """

        self._jitter_max = jitter_max

    @property
    def latency_max(self):
        """Gets the latency_max of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The latency_max of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: float
        """
        return self._latency_max

    @latency_max.setter
    def latency_max(self, latency_max):
        """Sets the latency_max of this TsoaPartialUserSrObject_.


        :param latency_max: The latency_max of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: float
        """

        self._latency_max = latency_max

    @property
    def price_max(self):
        """Gets the price_max of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The price_max of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: float
        """
        return self._price_max

    @price_max.setter
    def price_max(self, price_max):
        """Sets the price_max of this TsoaPartialUserSrObject_.


        :param price_max: The price_max of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: float
        """

        self._price_max = price_max

    @property
    def user_ipv4_source_addr(self):
        """Gets the user_ipv4_source_addr of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The user_ipv4_source_addr of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: str
        """
        return self._user_ipv4_source_addr

    @user_ipv4_source_addr.setter
    def user_ipv4_source_addr(self, user_ipv4_source_addr):
        """Sets the user_ipv4_source_addr of this TsoaPartialUserSrObject_.


        :param user_ipv4_source_addr: The user_ipv4_source_addr of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: str
        """

        self._user_ipv4_source_addr = user_ipv4_source_addr

    @property
    def user_ipv6_source_addr(self):
        """Gets the user_ipv6_source_addr of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The user_ipv6_source_addr of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: str
        """
        return self._user_ipv6_source_addr

    @user_ipv6_source_addr.setter
    def user_ipv6_source_addr(self, user_ipv6_source_addr):
        """Sets the user_ipv6_source_addr of this TsoaPartialUserSrObject_.


        :param user_ipv6_source_addr: The user_ipv6_source_addr of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: str
        """

        self._user_ipv6_source_addr = user_ipv6_source_addr

    @property
    def user_ipv4_dest_addr(self):
        """Gets the user_ipv4_dest_addr of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The user_ipv4_dest_addr of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: str
        """
        return self._user_ipv4_dest_addr

    @user_ipv4_dest_addr.setter
    def user_ipv4_dest_addr(self, user_ipv4_dest_addr):
        """Sets the user_ipv4_dest_addr of this TsoaPartialUserSrObject_.


        :param user_ipv4_dest_addr: The user_ipv4_dest_addr of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: str
        """

        self._user_ipv4_dest_addr = user_ipv4_dest_addr

    @property
    def user_ipv6_dest_addr(self):
        """Gets the user_ipv6_dest_addr of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The user_ipv6_dest_addr of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: str
        """
        return self._user_ipv6_dest_addr

    @user_ipv6_dest_addr.setter
    def user_ipv6_dest_addr(self, user_ipv6_dest_addr):
        """Sets the user_ipv6_dest_addr of this TsoaPartialUserSrObject_.


        :param user_ipv6_dest_addr: The user_ipv6_dest_addr of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: str
        """

        self._user_ipv6_dest_addr = user_ipv6_dest_addr

    @property
    def user_ipv4_dest_cidr(self):
        """Gets the user_ipv4_dest_cidr of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The user_ipv4_dest_cidr of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: str
        """
        return self._user_ipv4_dest_cidr

    @user_ipv4_dest_cidr.setter
    def user_ipv4_dest_cidr(self, user_ipv4_dest_cidr):
        """Sets the user_ipv4_dest_cidr of this TsoaPartialUserSrObject_.


        :param user_ipv4_dest_cidr: The user_ipv4_dest_cidr of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: str
        """

        self._user_ipv4_dest_cidr = user_ipv4_dest_cidr

    @property
    def user_ipv6_dest_cidr(self):
        """Gets the user_ipv6_dest_cidr of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The user_ipv6_dest_cidr of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: str
        """
        return self._user_ipv6_dest_cidr

    @user_ipv6_dest_cidr.setter
    def user_ipv6_dest_cidr(self, user_ipv6_dest_cidr):
        """Sets the user_ipv6_dest_cidr of this TsoaPartialUserSrObject_.


        :param user_ipv6_dest_cidr: The user_ipv6_dest_cidr of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: str
        """

        self._user_ipv6_dest_cidr = user_ipv6_dest_cidr

    @property
    def server_vpn_id(self):
        """Gets the server_vpn_id of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The server_vpn_id of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: float
        """
        return self._server_vpn_id

    @server_vpn_id.setter
    def server_vpn_id(self, server_vpn_id):
        """Sets the server_vpn_id of this TsoaPartialUserSrObject_.


        :param server_vpn_id: The server_vpn_id of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: float
        """

        self._server_vpn_id = server_vpn_id

    @property
    def server_vin_id(self):
        """Gets the server_vin_id of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The server_vin_id of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: float
        """
        return self._server_vin_id

    @server_vin_id.setter
    def server_vin_id(self, server_vin_id):
        """Sets the server_vin_id of this TsoaPartialUserSrObject_.


        :param server_vin_id: The server_vin_id of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: float
        """

        self._server_vin_id = server_vin_id

    @property
    def server_ven_id(self):
        """Gets the server_ven_id of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The server_ven_id of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: float
        """
        return self._server_ven_id

    @server_ven_id.setter
    def server_ven_id(self, server_ven_id):
        """Sets the server_ven_id of this TsoaPartialUserSrObject_.


        :param server_ven_id: The server_ven_id of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: float
        """

        self._server_ven_id = server_ven_id

    @property
    def sr_policy_id(self):
        """Gets the sr_policy_id of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The sr_policy_id of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: float
        """
        return self._sr_policy_id

    @sr_policy_id.setter
    def sr_policy_id(self, sr_policy_id):
        """Sets the sr_policy_id of this TsoaPartialUserSrObject_.


        :param sr_policy_id: The sr_policy_id of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: float
        """

        self._sr_policy_id = sr_policy_id

    @property
    def user_sr_direction(self):
        """Gets the user_sr_direction of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The user_sr_direction of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: UserSrDirection
        """
        return self._user_sr_direction

    @user_sr_direction.setter
    def user_sr_direction(self, user_sr_direction):
        """Sets the user_sr_direction of this TsoaPartialUserSrObject_.


        :param user_sr_direction: The user_sr_direction of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: UserSrDirection
        """

        self._user_sr_direction = user_sr_direction

    @property
    def user_sr_status(self):
        """Gets the user_sr_status of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The user_sr_status of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: Status
        """
        return self._user_sr_status

    @user_sr_status.setter
    def user_sr_status(self, user_sr_status):
        """Sets the user_sr_status of this TsoaPartialUserSrObject_.


        :param user_sr_status: The user_sr_status of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: Status
        """

        self._user_sr_status = user_sr_status

    @property
    def user_sr_status_reason(self):
        """Gets the user_sr_status_reason of this TsoaPartialUserSrObject_.  # noqa: E501


        :return: The user_sr_status_reason of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: str
        """
        return self._user_sr_status_reason

    @user_sr_status_reason.setter
    def user_sr_status_reason(self, user_sr_status_reason):
        """Sets the user_sr_status_reason of this TsoaPartialUserSrObject_.


        :param user_sr_status_reason: The user_sr_status_reason of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: str
        """

        self._user_sr_status_reason = user_sr_status_reason

    @property
    def user_sr_is_via_sdn(self):
        """Gets the user_sr_is_via_sdn of this TsoaPartialUserSrObject_.  # noqa: E501

        Indicates if current configuration routes traffic via SDN.  # noqa: E501

        :return: The user_sr_is_via_sdn of this TsoaPartialUserSrObject_.  # noqa: E501
        :rtype: bool
        """
        return self._user_sr_is_via_sdn

    @user_sr_is_via_sdn.setter
    def user_sr_is_via_sdn(self, user_sr_is_via_sdn):
        """Sets the user_sr_is_via_sdn of this TsoaPartialUserSrObject_.

        Indicates if current configuration routes traffic via SDN.  # noqa: E501

        :param user_sr_is_via_sdn: The user_sr_is_via_sdn of this TsoaPartialUserSrObject_.  # noqa: E501
        :type: bool
        """

        self._user_sr_is_via_sdn = user_sr_is_via_sdn

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(TsoaPartialUserSrObject_, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TsoaPartialUserSrObject_):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TsoaPartialLinkObject_(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "lang_id": "float",
        "link_weight": "float",
        "link_title": "str",
        "link_url": "str",
        "link_type": "ContextType",
        "link_img_url": "str",
        "link_visibility": "VisibilityType",
    }

    attribute_map = {
        "lang_id": "lang_id",
        "link_weight": "link_weight",
        "link_title": "link_title",
        "link_url": "link_url",
        "link_type": "link_type",
        "link_img_url": "link_img_url",
        "link_visibility": "link_visibility",
    }

    def __init__(
        self,
        lang_id=None,
        link_weight=None,
        link_title=None,
        link_url=None,
        link_type=None,
        link_img_url=None,
        link_visibility=None,
    ):  # noqa: E501
        """TsoaPartialLinkObject_ - a model defined in Swagger"""  # noqa: E501
        self._lang_id = None
        self._link_weight = None
        self._link_title = None
        self._link_url = None
        self._link_type = None
        self._link_img_url = None
        self._link_visibility = None
        self.discriminator = None
        if lang_id is not None:
            self.lang_id = lang_id
        if link_weight is not None:
            self.link_weight = link_weight
        if link_title is not None:
            self.link_title = link_title
        if link_url is not None:
            self.link_url = link_url
        if link_type is not None:
            self.link_type = link_type
        if link_img_url is not None:
            self.link_img_url = link_img_url
        if link_visibility is not None:
            self.link_visibility = link_visibility

    @property
    def lang_id(self):
        """Gets the lang_id of this TsoaPartialLinkObject_.  # noqa: E501


        :return: The lang_id of this TsoaPartialLinkObject_.  # noqa: E501
        :rtype: float
        """
        return self._lang_id

    @lang_id.setter
    def lang_id(self, lang_id):
        """Sets the lang_id of this TsoaPartialLinkObject_.


        :param lang_id: The lang_id of this TsoaPartialLinkObject_.  # noqa: E501
        :type: float
        """

        self._lang_id = lang_id

    @property
    def link_weight(self):
        """Gets the link_weight of this TsoaPartialLinkObject_.  # noqa: E501


        :return: The link_weight of this TsoaPartialLinkObject_.  # noqa: E501
        :rtype: float
        """
        return self._link_weight

    @link_weight.setter
    def link_weight(self, link_weight):
        """Sets the link_weight of this TsoaPartialLinkObject_.


        :param link_weight: The link_weight of this TsoaPartialLinkObject_.  # noqa: E501
        :type: float
        """

        self._link_weight = link_weight

    @property
    def link_title(self):
        """Gets the link_title of this TsoaPartialLinkObject_.  # noqa: E501


        :return: The link_title of this TsoaPartialLinkObject_.  # noqa: E501
        :rtype: str
        """
        return self._link_title

    @link_title.setter
    def link_title(self, link_title):
        """Sets the link_title of this TsoaPartialLinkObject_.


        :param link_title: The link_title of this TsoaPartialLinkObject_.  # noqa: E501
        :type: str
        """

        self._link_title = link_title

    @property
    def link_url(self):
        """Gets the link_url of this TsoaPartialLinkObject_.  # noqa: E501


        :return: The link_url of this TsoaPartialLinkObject_.  # noqa: E501
        :rtype: str
        """
        return self._link_url

    @link_url.setter
    def link_url(self, link_url):
        """Sets the link_url of this TsoaPartialLinkObject_.


        :param link_url: The link_url of this TsoaPartialLinkObject_.  # noqa: E501
        :type: str
        """

        self._link_url = link_url

    @property
    def link_type(self):
        """Gets the link_type of this TsoaPartialLinkObject_.  # noqa: E501


        :return: The link_type of this TsoaPartialLinkObject_.  # noqa: E501
        :rtype: ContextType
        """
        return self._link_type

    @link_type.setter
    def link_type(self, link_type):
        """Sets the link_type of this TsoaPartialLinkObject_.


        :param link_type: The link_type of this TsoaPartialLinkObject_.  # noqa: E501
        :type: ContextType
        """

        self._link_type = link_type

    @property
    def link_img_url(self):
        """Gets the link_img_url of this TsoaPartialLinkObject_.  # noqa: E501


        :return: The link_img_url of this TsoaPartialLinkObject_.  # noqa: E501
        :rtype: str
        """
        return self._link_img_url

    @link_img_url.setter
    def link_img_url(self, link_img_url):
        """Sets the link_img_url of this TsoaPartialLinkObject_.


        :param link_img_url: The link_img_url of this TsoaPartialLinkObject_.  # noqa: E501
        :type: str
        """

        self._link_img_url = link_img_url

    @property
    def link_visibility(self):
        """Gets the link_visibility of this TsoaPartialLinkObject_.  # noqa: E501


        :return: The link_visibility of this TsoaPartialLinkObject_.  # noqa: E501
        :rtype: VisibilityType
        """
        return self._link_visibility

    @link_visibility.setter
    def link_visibility(self, link_visibility):
        """Sets the link_visibility of this TsoaPartialLinkObject_.


        :param link_visibility: The link_visibility of this TsoaPartialLinkObject_.  # noqa: E501
        :type: VisibilityType
        """

        self._link_visibility = link_visibility

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(TsoaPartialLinkObject_, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TsoaPartialLinkObject_):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class WgAddPeerMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "allowed_ips_info": "list[WgAddPeerMetadataAllowedIpsInfo]",
        "link_tag": "LinkTag",
        "agent_id": "float",
        "connection_id": "float",
        "device_public_ipv4": "str",
        "device_name": "str",
        "device_id": "str",
    }

    attribute_map = {
        "allowed_ips_info": "allowed_ips_info",
        "link_tag": "link_tag",
        "agent_id": "agent_id",
        "connection_id": "connection_id",
        "device_public_ipv4": "device_public_ipv4",
        "device_name": "device_name",
        "device_id": "device_id",
    }

    def __init__(
        self,
        allowed_ips_info=None,
        link_tag=None,
        agent_id=None,
        connection_id=None,
        device_public_ipv4=None,
        device_name=None,
        device_id=None,
    ):  # noqa: E501
        """WgAddPeerMetadata - a model defined in Swagger"""  # noqa: E501
        self._allowed_ips_info = None
        self._link_tag = None
        self._agent_id = None
        self._connection_id = None
        self._device_public_ipv4 = None
        self._device_name = None
        self._device_id = None
        self.discriminator = None
        self.allowed_ips_info = allowed_ips_info
        self.link_tag = link_tag
        self.agent_id = agent_id
        self.connection_id = connection_id
        self.device_public_ipv4 = device_public_ipv4
        self.device_name = device_name
        self.device_id = device_id

    @property
    def allowed_ips_info(self):
        """Gets the allowed_ips_info of this WgAddPeerMetadata.  # noqa: E501


        :return: The allowed_ips_info of this WgAddPeerMetadata.  # noqa: E501
        :rtype: list[WgAddPeerMetadataAllowedIpsInfo]
        """
        return self._allowed_ips_info

    @allowed_ips_info.setter
    def allowed_ips_info(self, allowed_ips_info):
        """Sets the allowed_ips_info of this WgAddPeerMetadata.


        :param allowed_ips_info: The allowed_ips_info of this WgAddPeerMetadata.  # noqa: E501
        :type: list[WgAddPeerMetadataAllowedIpsInfo]
        """
        if allowed_ips_info is None:
            raise ValueError(
                "Invalid value for `allowed_ips_info`, must not be `None`"
            )  # noqa: E501

        self._allowed_ips_info = allowed_ips_info

    @property
    def link_tag(self):
        """Gets the link_tag of this WgAddPeerMetadata.  # noqa: E501


        :return: The link_tag of this WgAddPeerMetadata.  # noqa: E501
        :rtype: LinkTag
        """
        return self._link_tag

    @link_tag.setter
    def link_tag(self, link_tag):
        """Sets the link_tag of this WgAddPeerMetadata.


        :param link_tag: The link_tag of this WgAddPeerMetadata.  # noqa: E501
        :type: LinkTag
        """
        if link_tag is None:
            raise ValueError(
                "Invalid value for `link_tag`, must not be `None`"
            )  # noqa: E501

        self._link_tag = link_tag

    @property
    def agent_id(self):
        """Gets the agent_id of this WgAddPeerMetadata.  # noqa: E501


        :return: The agent_id of this WgAddPeerMetadata.  # noqa: E501
        :rtype: float
        """
        return self._agent_id

    @agent_id.setter
    def agent_id(self, agent_id):
        """Sets the agent_id of this WgAddPeerMetadata.


        :param agent_id: The agent_id of this WgAddPeerMetadata.  # noqa: E501
        :type: float
        """
        if agent_id is None:
            raise ValueError(
                "Invalid value for `agent_id`, must not be `None`"
            )  # noqa: E501

        self._agent_id = agent_id

    @property
    def connection_id(self):
        """Gets the connection_id of this WgAddPeerMetadata.  # noqa: E501


        :return: The connection_id of this WgAddPeerMetadata.  # noqa: E501
        :rtype: float
        """
        return self._connection_id

    @connection_id.setter
    def connection_id(self, connection_id):
        """Sets the connection_id of this WgAddPeerMetadata.


        :param connection_id: The connection_id of this WgAddPeerMetadata.  # noqa: E501
        :type: float
        """
        if connection_id is None:
            raise ValueError(
                "Invalid value for `connection_id`, must not be `None`"
            )  # noqa: E501

        self._connection_id = connection_id

    @property
    def device_public_ipv4(self):
        """Gets the device_public_ipv4 of this WgAddPeerMetadata.  # noqa: E501


        :return: The device_public_ipv4 of this WgAddPeerMetadata.  # noqa: E501
        :rtype: str
        """
        return self._device_public_ipv4

    @device_public_ipv4.setter
    def device_public_ipv4(self, device_public_ipv4):
        """Sets the device_public_ipv4 of this WgAddPeerMetadata.


        :param device_public_ipv4: The device_public_ipv4 of this WgAddPeerMetadata.  # noqa: E501
        :type: str
        """
        if device_public_ipv4 is None:
            raise ValueError(
                "Invalid value for `device_public_ipv4`, must not be `None`"
            )  # noqa: E501

        self._device_public_ipv4 = device_public_ipv4

    @property
    def device_name(self):
        """Gets the device_name of this WgAddPeerMetadata.  # noqa: E501


        :return: The device_name of this WgAddPeerMetadata.  # noqa: E501
        :rtype: str
        """
        return self._device_name

    @device_name.setter
    def device_name(self, device_name):
        """Sets the device_name of this WgAddPeerMetadata.


        :param device_name: The device_name of this WgAddPeerMetadata.  # noqa: E501
        :type: str
        """
        if device_name is None:
            raise ValueError(
                "Invalid value for `device_name`, must not be `None`"
            )  # noqa: E501

        self._device_name = device_name

    @property
    def device_id(self):
        """Gets the device_id of this WgAddPeerMetadata.  # noqa: E501


        :return: The device_id of this WgAddPeerMetadata.  # noqa: E501
        :rtype: str
        """
        return self._device_id

    @device_id.setter
    def device_id(self, device_id):
        """Sets the device_id of this WgAddPeerMetadata.


        :param device_id: The device_id of this WgAddPeerMetadata.  # noqa: E501
        :type: str
        """
        if device_id is None:
            raise ValueError(
                "Invalid value for `device_id`, must not be `None`"
            )  # noqa: E501

        self._device_id = device_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(WgAddPeerMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WgAddPeerMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    syntropy-auth-service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from syntropy_sdk.api_client import ApiClient


class ApiKeysApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_api_key(self, body, **kwargs):  # noqa: E501
        """create_api_key  # noqa: E501

        Creates API key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_api_key(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ApiKeyCreateRequest body: (required)
        :return: ApiResponseApiKeyObject_
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.create_api_key_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_api_key_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_api_key_with_http_info(self, body, **kwargs):  # noqa: E501
        """create_api_key  # noqa: E501

        Creates API key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_api_key_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ApiKeyCreateRequest body: (required)
        :return: ApiResponseApiKeyObject_
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_api_key" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `create_api_key`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/auth/api-key",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ApiResponseApiKeyObject_",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def delete_api_key(self, api_key_id, **kwargs):  # noqa: E501
        """delete_api_key  # noqa: E501

        Deletes API key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_api_key(api_key_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float api_key_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.delete_api_key_with_http_info(
                api_key_id, **kwargs
            )  # noqa: E501
        else:
            (data) = self.delete_api_key_with_http_info(
                api_key_id, **kwargs
            )  # noqa: E501
            return data

    def delete_api_key_with_http_info(self, api_key_id, **kwargs):  # noqa: E501
        """delete_api_key  # noqa: E501

        Deletes API key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_api_key_with_http_info(api_key_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float api_key_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["api_key_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_api_key" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'api_key_id' is set
        if "api_key_id" not in params or params["api_key_id"] is None:
            raise ValueError(
                "Missing the required parameter `api_key_id` when calling `delete_api_key`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "api_key_id" in params:
            path_params["api_key_id"] = params["api_key_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/auth/api-key/{api_key_id}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_api_key(self, **kwargs):  # noqa: E501
        """get_api_key  # noqa: E501

        Get API keys.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_api_key(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float skip:
        :param float take:
        :param str order: string: \"ASC\" | \"DESC\"
        :param str filter: api_key_id: string, api_key_name: string
        :return: ApiResponseApiKeyDtoArray_
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.get_api_key_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_api_key_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_api_key_with_http_info(self, **kwargs):  # noqa: E501
        """get_api_key  # noqa: E501

        Get API keys.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_api_key_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float skip:
        :param float take:
        :param str order: string: \"ASC\" | \"DESC\"
        :param str filter: api_key_id: string, api_key_name: string
        :return: ApiResponseApiKeyDtoArray_
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["skip", "take", "order", "filter"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_api_key" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "skip" in params:
            query_params.append(("skip", params["skip"]))  # noqa: E501
        if "take" in params:
            query_params.append(("take", params["take"]))  # noqa: E501
        if "order" in params:
            query_params.append(("order", params["order"]))  # noqa: E501
        if "filter" in params:
            query_params.append(("filter", params["filter"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/auth/api-key",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ApiResponseApiKeyDtoArray_",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TsoaPartialColorObject_(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "color_id": "float",
        "color_bandwidth": "ConstraintEnum",
        "color_jitter": "ConstraintEnum",
        "color_latency": "ConstraintEnum",
        "color_price": "ConstraintEnum",
    }

    attribute_map = {
        "color_id": "color_id",
        "color_bandwidth": "color_bandwidth",
        "color_jitter": "color_jitter",
        "color_latency": "color_latency",
        "color_price": "color_price",
    }

    def __init__(
        self,
        color_id=None,
        color_bandwidth=None,
        color_jitter=None,
        color_latency=None,
        color_price=None,
    ):  # noqa: E501
        """TsoaPartialColorObject_ - a model defined in Swagger"""  # noqa: E501
        self._color_id = None
        self._color_bandwidth = None
        self._color_jitter = None
        self._color_latency = None
        self._color_price = None
        self.discriminator = None
        if color_id is not None:
            self.color_id = color_id
        if color_bandwidth is not None:
            self.color_bandwidth = color_bandwidth
        if color_jitter is not None:
            self.color_jitter = color_jitter
        if color_latency is not None:
            self.color_latency = color_latency
        if color_price is not None:
            self.color_price = color_price

    @property
    def color_id(self):
        """Gets the color_id of this TsoaPartialColorObject_.  # noqa: E501


        :return: The color_id of this TsoaPartialColorObject_.  # noqa: E501
        :rtype: float
        """
        return self._color_id

    @color_id.setter
    def color_id(self, color_id):
        """Sets the color_id of this TsoaPartialColorObject_.


        :param color_id: The color_id of this TsoaPartialColorObject_.  # noqa: E501
        :type: float
        """

        self._color_id = color_id

    @property
    def color_bandwidth(self):
        """Gets the color_bandwidth of this TsoaPartialColorObject_.  # noqa: E501


        :return: The color_bandwidth of this TsoaPartialColorObject_.  # noqa: E501
        :rtype: ConstraintEnum
        """
        return self._color_bandwidth

    @color_bandwidth.setter
    def color_bandwidth(self, color_bandwidth):
        """Sets the color_bandwidth of this TsoaPartialColorObject_.


        :param color_bandwidth: The color_bandwidth of this TsoaPartialColorObject_.  # noqa: E501
        :type: ConstraintEnum
        """

        self._color_bandwidth = color_bandwidth

    @property
    def color_jitter(self):
        """Gets the color_jitter of this TsoaPartialColorObject_.  # noqa: E501


        :return: The color_jitter of this TsoaPartialColorObject_.  # noqa: E501
        :rtype: ConstraintEnum
        """
        return self._color_jitter

    @color_jitter.setter
    def color_jitter(self, color_jitter):
        """Sets the color_jitter of this TsoaPartialColorObject_.


        :param color_jitter: The color_jitter of this TsoaPartialColorObject_.  # noqa: E501
        :type: ConstraintEnum
        """

        self._color_jitter = color_jitter

    @property
    def color_latency(self):
        """Gets the color_latency of this TsoaPartialColorObject_.  # noqa: E501


        :return: The color_latency of this TsoaPartialColorObject_.  # noqa: E501
        :rtype: ConstraintEnum
        """
        return self._color_latency

    @color_latency.setter
    def color_latency(self, color_latency):
        """Sets the color_latency of this TsoaPartialColorObject_.


        :param color_latency: The color_latency of this TsoaPartialColorObject_.  # noqa: E501
        :type: ConstraintEnum
        """

        self._color_latency = color_latency

    @property
    def color_price(self):
        """Gets the color_price of this TsoaPartialColorObject_.  # noqa: E501


        :return: The color_price of this TsoaPartialColorObject_.  # noqa: E501
        :rtype: ConstraintEnum
        """
        return self._color_price

    @color_price.setter
    def color_price(self, color_price):
        """Sets the color_price of this TsoaPartialColorObject_.


        :param color_price: The color_price of this TsoaPartialColorObject_.  # noqa: E501
        :type: ConstraintEnum
        """

        self._color_price = color_price

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(TsoaPartialColorObject_, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TsoaPartialColorObject_):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import json
import time

from syntropy_sdk import ApiClient, AuthApi, Configuration, MetadataNetworkType, models
from syntropy_sdk.exceptions import *

TAKE_MAX_ITEMS_PER_CALL = 2048
MAX_PAYLOAD_SIZE = 99 * 1024
MAX_QUERY_FIELD_SIZE = 2 * 1024

ALLOWED_NETWORK_TOPOLOGIES = (
    MetadataNetworkType.P2P,
    MetadataNetworkType.P2M,
    MetadataNetworkType.MESH,
)


class WithRetry:
    """Call api method several times in case of an error. Implements exponential back-off without jitter.

    Example:
        WithRetry(auth_api.login)("username", "password")
    """

    def __init__(self, func, retry_count=7, base=15, exponent=1, cap=180):
        self.func = func
        self.retry_count = retry_count
        self.base = base
        self.exponent = exponent
        self.cap = cap

    def __call__(self, *args, **kwargs):
        for attempt in range(self.retry_count):
            try:
                return self.func(*args, **kwargs)
            except ApiException as err:
                if err.status not in (500, 502, 503, 504, 408, 429):
                    raise
                # NOTE: This check is specifically for attempting to create connections just after the network was created.
                # In such a case the network ID is returned by the create_network api call, however, it is not yet being seen
                # by subsequent create_connections call if it is made too quickly.
                if err.status == 400 and attempt:
                    raise
                if attempt >= self.retry_count - 1:
                    raise
                delay = min(self.cap, self.base * 2 ** (attempt * self.exponent))
                time.sleep(delay)


def _default_translator(field):
    def translator(body, data):
        if data is None:
            return body[field]
        else:
            return {
                **body,
                field: data,
            }

    return translator


class BatchedRequest:
    """Executes requests in batches in order to circumvent payload/field size limit.
    Assumes that the batchable parameter is a list/tuple and api call returns a list.

    Translator must be provided for requests that have "body" as a kwarg. The translator
    is a callable that accepts the body as first argument and batch data as the second argument.
    It must return the list if the second argument is None and the payload body otherwise.
    It must not modify the body.

    Example translator:
        def translator(body, data):
            if data is None:
                return body["data"]
            else:
                return {
                    **body,
                    "data": data,
                }

    Example usage:
        BatchedRequest(
            api.update_connection_services,
            max_payload_size=MAX_PAYLOAD_SIZE,
            translator=_default_translator("changes"),
        )(body=body)
    """

    def __init__(
        self,
        func,
        max_payload_size,
        translator=_default_translator("data"),
    ):
        self.func = func
        self.max_payload_size = max_payload_size
        self.translator = translator

    def __call__(self, *args, **kwargs):
        raise NotImplementedError

    def _calculate_payload_size(self, data):
        if isinstance(data, list):
            return len(",".join(str(i) for i in data))
        else:
            return len(json.dumps(data))

    def _determine_batch_size(self, body, data, batch_size):
        while batch_size:
            data = data[:batch_size]
            batch = self.translator(body, data) if body is not None else data
            if self._calculate_payload_size(batch) > self.max_payload_size:
                batch_size //= 2
            else:
                return batch_size, batch
        raise SyntropyError("Batch size could not be determined")

    def _generate_batches(self, body, data):
        batch_size = len(data)
        while data:
            batch_size, batch = self._determine_batch_size(body, data, batch_size)
            data = data[batch_size:]
            yield batch

    def _call(self, body, data, *args, **kwargs):
        result = []
        for batch in self._generate_batches(body, data):
            # TODO: What to do with errors in result?
            func = WithRetry(self.func)
            if body is None:
                response = func(batch, *args, **kwargs)
            else:
                response = func(body=batch, *args, **kwargs)
            if isinstance(response, dict) and "data" in response:
                result += response["data"]
            else:
                result.append(response)
        # NOTE: Undesirable side effect: will transform non-list responses to {"data": data}
        return {"data": result}


class BatchedRequestBody(BatchedRequest):
    def __init__(
        self,
        func,
        max_payload_size,
        translator=_default_translator("data"),
    ):
        super().__init__(func, max_payload_size, translator=translator)

    def __call__(self, *args, **kwargs):
        body = kwargs.pop("body")
        data = self.translator(body, None)
        return self._call(body, data, *args, **kwargs)


class BatchedRequestQuery(BatchedRequest):
    def __init__(
        self,
        func,
        max_query_size,
    ):
        super().__init__(func, max_query_size)

    def __call__(self, *args, **kwargs):
        query = args[0]
        args = args[1:]
        return self._call(None, query, *args, **kwargs)


class BatchedRequestFilter(BatchedRequest):
    def __init__(
        self,
        func,
        max_query_size,
        filter_name,
        filter_data,
    ):
        super().__init__(func, max_query_size)
        self.filter_name = filter_name
        self.filter_data = filter_data
        self._original_filter_size = 0

    def _calculate_payload_size(self, data):
        return (
            len(";".join(str(i) for i in data))
            + len(f"{self.filter_name}[]:")
            + self._original_filter_size
        )

    def __call__(self, *args, **kwargs):
        result = []
        original_filter = []
        if "filter" in kwargs:
            original_filter = [kwargs["filter"]]
            self._original_filter_size = len(kwargs["filter"])
            del kwargs["filter"]

        for batch in self._generate_batches(None, self.filter_data):
            func = WithRetry(self.func)

            filter_batch = f"{self.filter_name}[]:{';'.join(str(i) for i in batch)}"
            filters = original_filter + [filter_batch]
            new_filter = ",".join(filters)
            response = func(filter=new_filter, *args, **kwargs)

            if isinstance(response, dict) and "data" in response:
                result += response["data"]
            else:
                result.append(response)
        # NOTE: Undesirable side effect: will transform non-list responses to {"data": data}
        return {"data": result}


def login_with_access_token(api_url, access_token):
    """Exchange access token retrieved from the Platform for JWT access token.
    JWT access token can be used to make Platform API calls.
    """
    config = Configuration()
    config.host = api_url
    api = ApiClient(config)
    auth = AuthApi(api)

    body = models.AccessTokenData(access_token=access_token)
    try:
        response = auth.auth_access_token_login(body)
        return response.access_token
    finally:
        del auth
        del api



# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TsoaPartialAgentInterfaceObject_(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "agent_id": "float",
        "user_id": "float",
        "agent_interface_is_configured": "bool",
        "agent_interface_link_tag": "LinkTag",
        "agent_interface_name": "str",
        "agent_interface_public_key": "str",
        "agent_interface_endpoint_ipv4": "str",
        "agent_interface_endpoint_port": "float",
        "agent_interface_internal_ipv4": "str",
    }

    attribute_map = {
        "agent_id": "agent_id",
        "user_id": "user_id",
        "agent_interface_is_configured": "agent_interface_is_configured",
        "agent_interface_link_tag": "agent_interface_link_tag",
        "agent_interface_name": "agent_interface_name",
        "agent_interface_public_key": "agent_interface_public_key",
        "agent_interface_endpoint_ipv4": "agent_interface_endpoint_ipv4",
        "agent_interface_endpoint_port": "agent_interface_endpoint_port",
        "agent_interface_internal_ipv4": "agent_interface_internal_ipv4",
    }

    def __init__(
        self,
        agent_id=None,
        user_id=None,
        agent_interface_is_configured=None,
        agent_interface_link_tag=None,
        agent_interface_name=None,
        agent_interface_public_key=None,
        agent_interface_endpoint_ipv4=None,
        agent_interface_endpoint_port=None,
        agent_interface_internal_ipv4=None,
    ):  # noqa: E501
        """TsoaPartialAgentInterfaceObject_ - a model defined in Swagger"""  # noqa: E501
        self._agent_id = None
        self._user_id = None
        self._agent_interface_is_configured = None
        self._agent_interface_link_tag = None
        self._agent_interface_name = None
        self._agent_interface_public_key = None
        self._agent_interface_endpoint_ipv4 = None
        self._agent_interface_endpoint_port = None
        self._agent_interface_internal_ipv4 = None
        self.discriminator = None
        if agent_id is not None:
            self.agent_id = agent_id
        if user_id is not None:
            self.user_id = user_id
        if agent_interface_is_configured is not None:
            self.agent_interface_is_configured = agent_interface_is_configured
        if agent_interface_link_tag is not None:
            self.agent_interface_link_tag = agent_interface_link_tag
        if agent_interface_name is not None:
            self.agent_interface_name = agent_interface_name
        if agent_interface_public_key is not None:
            self.agent_interface_public_key = agent_interface_public_key
        if agent_interface_endpoint_ipv4 is not None:
            self.agent_interface_endpoint_ipv4 = agent_interface_endpoint_ipv4
        if agent_interface_endpoint_port is not None:
            self.agent_interface_endpoint_port = agent_interface_endpoint_port
        if agent_interface_internal_ipv4 is not None:
            self.agent_interface_internal_ipv4 = agent_interface_internal_ipv4

    @property
    def agent_id(self):
        """Gets the agent_id of this TsoaPartialAgentInterfaceObject_.  # noqa: E501


        :return: The agent_id of this TsoaPartialAgentInterfaceObject_.  # noqa: E501
        :rtype: float
        """
        return self._agent_id

    @agent_id.setter
    def agent_id(self, agent_id):
        """Sets the agent_id of this TsoaPartialAgentInterfaceObject_.


        :param agent_id: The agent_id of this TsoaPartialAgentInterfaceObject_.  # noqa: E501
        :type: float
        """

        self._agent_id = agent_id

    @property
    def user_id(self):
        """Gets the user_id of this TsoaPartialAgentInterfaceObject_.  # noqa: E501


        :return: The user_id of this TsoaPartialAgentInterfaceObject_.  # noqa: E501
        :rtype: float
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this TsoaPartialAgentInterfaceObject_.


        :param user_id: The user_id of this TsoaPartialAgentInterfaceObject_.  # noqa: E501
        :type: float
        """

        self._user_id = user_id

    @property
    def agent_interface_is_configured(self):
        """Gets the agent_interface_is_configured of this TsoaPartialAgentInterfaceObject_.  # noqa: E501


        :return: The agent_interface_is_configured of this TsoaPartialAgentInterfaceObject_.  # noqa: E501
        :rtype: bool
        """
        return self._agent_interface_is_configured

    @agent_interface_is_configured.setter
    def agent_interface_is_configured(self, agent_interface_is_configured):
        """Sets the agent_interface_is_configured of this TsoaPartialAgentInterfaceObject_.


        :param agent_interface_is_configured: The agent_interface_is_configured of this TsoaPartialAgentInterfaceObject_.  # noqa: E501
        :type: bool
        """

        self._agent_interface_is_configured = agent_interface_is_configured

    @property
    def agent_interface_link_tag(self):
        """Gets the agent_interface_link_tag of this TsoaPartialAgentInterfaceObject_.  # noqa: E501


        :return: The agent_interface_link_tag of this TsoaPartialAgentInterfaceObject_.  # noqa: E501
        :rtype: LinkTag
        """
        return self._agent_interface_link_tag

    @agent_interface_link_tag.setter
    def agent_interface_link_tag(self, agent_interface_link_tag):
        """Sets the agent_interface_link_tag of this TsoaPartialAgentInterfaceObject_.


        :param agent_interface_link_tag: The agent_interface_link_tag of this TsoaPartialAgentInterfaceObject_.  # noqa: E501
        :type: LinkTag
        """

        self._agent_interface_link_tag = agent_interface_link_tag

    @property
    def agent_interface_name(self):
        """Gets the agent_interface_name of this TsoaPartialAgentInterfaceObject_.  # noqa: E501


        :return: The agent_interface_name of this TsoaPartialAgentInterfaceObject_.  # noqa: E501
        :rtype: str
        """
        return self._agent_interface_name

    @agent_interface_name.setter
    def agent_interface_name(self, agent_interface_name):
        """Sets the agent_interface_name of this TsoaPartialAgentInterfaceObject_.


        :param agent_interface_name: The agent_interface_name of this TsoaPartialAgentInterfaceObject_.  # noqa: E501
        :type: str
        """

        self._agent_interface_name = agent_interface_name

    @property
    def agent_interface_public_key(self):
        """Gets the agent_interface_public_key of this TsoaPartialAgentInterfaceObject_.  # noqa: E501


        :return: The agent_interface_public_key of this TsoaPartialAgentInterfaceObject_.  # noqa: E501
        :rtype: str
        """
        return self._agent_interface_public_key

    @agent_interface_public_key.setter
    def agent_interface_public_key(self, agent_interface_public_key):
        """Sets the agent_interface_public_key of this TsoaPartialAgentInterfaceObject_.


        :param agent_interface_public_key: The agent_interface_public_key of this TsoaPartialAgentInterfaceObject_.  # noqa: E501
        :type: str
        """

        self._agent_interface_public_key = agent_interface_public_key

    @property
    def agent_interface_endpoint_ipv4(self):
        """Gets the agent_interface_endpoint_ipv4 of this TsoaPartialAgentInterfaceObject_.  # noqa: E501


        :return: The agent_interface_endpoint_ipv4 of this TsoaPartialAgentInterfaceObject_.  # noqa: E501
        :rtype: str
        """
        return self._agent_interface_endpoint_ipv4

    @agent_interface_endpoint_ipv4.setter
    def agent_interface_endpoint_ipv4(self, agent_interface_endpoint_ipv4):
        """Sets the agent_interface_endpoint_ipv4 of this TsoaPartialAgentInterfaceObject_.


        :param agent_interface_endpoint_ipv4: The agent_interface_endpoint_ipv4 of this TsoaPartialAgentInterfaceObject_.  # noqa: E501
        :type: str
        """

        self._agent_interface_endpoint_ipv4 = agent_interface_endpoint_ipv4

    @property
    def agent_interface_endpoint_port(self):
        """Gets the agent_interface_endpoint_port of this TsoaPartialAgentInterfaceObject_.  # noqa: E501


        :return: The agent_interface_endpoint_port of this TsoaPartialAgentInterfaceObject_.  # noqa: E501
        :rtype: float
        """
        return self._agent_interface_endpoint_port

    @agent_interface_endpoint_port.setter
    def agent_interface_endpoint_port(self, agent_interface_endpoint_port):
        """Sets the agent_interface_endpoint_port of this TsoaPartialAgentInterfaceObject_.


        :param agent_interface_endpoint_port: The agent_interface_endpoint_port of this TsoaPartialAgentInterfaceObject_.  # noqa: E501
        :type: float
        """

        self._agent_interface_endpoint_port = agent_interface_endpoint_port

    @property
    def agent_interface_internal_ipv4(self):
        """Gets the agent_interface_internal_ipv4 of this TsoaPartialAgentInterfaceObject_.  # noqa: E501


        :return: The agent_interface_internal_ipv4 of this TsoaPartialAgentInterfaceObject_.  # noqa: E501
        :rtype: str
        """
        return self._agent_interface_internal_ipv4

    @agent_interface_internal_ipv4.setter
    def agent_interface_internal_ipv4(self, agent_interface_internal_ipv4):
        """Sets the agent_interface_internal_ipv4 of this TsoaPartialAgentInterfaceObject_.


        :param agent_interface_internal_ipv4: The agent_interface_internal_ipv4 of this TsoaPartialAgentInterfaceObject_.  # noqa: E501
        :type: str
        """

        self._agent_interface_internal_ipv4 = agent_interface_internal_ipv4

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(TsoaPartialAgentInterfaceObject_, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TsoaPartialAgentInterfaceObject_):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TsoaPartialInterfaceObject_(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "interface_name": "str",
        "interface_type": "InterfaceType",
        "server_id": "float",
        "server_cidr_ipv4": "str",
        "server_cidr_ipv6": "str",
        "interface_monitoring_cidr": "str",
        "interface_kvm_gateway_ipv4": "str",
        "interface_additional_routes_cidrs": "str",
    }

    attribute_map = {
        "interface_name": "interface_name",
        "interface_type": "interface_type",
        "server_id": "server_id",
        "server_cidr_ipv4": "server_cidr_ipv4",
        "server_cidr_ipv6": "server_cidr_ipv6",
        "interface_monitoring_cidr": "interface_monitoring_cidr",
        "interface_kvm_gateway_ipv4": "interface_kvm_gateway_ipv4",
        "interface_additional_routes_cidrs": "interface_additional_routes_cidrs",
    }

    def __init__(
        self,
        interface_name=None,
        interface_type=None,
        server_id=None,
        server_cidr_ipv4=None,
        server_cidr_ipv6=None,
        interface_monitoring_cidr=None,
        interface_kvm_gateway_ipv4=None,
        interface_additional_routes_cidrs=None,
    ):  # noqa: E501
        """TsoaPartialInterfaceObject_ - a model defined in Swagger"""  # noqa: E501
        self._interface_name = None
        self._interface_type = None
        self._server_id = None
        self._server_cidr_ipv4 = None
        self._server_cidr_ipv6 = None
        self._interface_monitoring_cidr = None
        self._interface_kvm_gateway_ipv4 = None
        self._interface_additional_routes_cidrs = None
        self.discriminator = None
        if interface_name is not None:
            self.interface_name = interface_name
        if interface_type is not None:
            self.interface_type = interface_type
        if server_id is not None:
            self.server_id = server_id
        if server_cidr_ipv4 is not None:
            self.server_cidr_ipv4 = server_cidr_ipv4
        if server_cidr_ipv6 is not None:
            self.server_cidr_ipv6 = server_cidr_ipv6
        if interface_monitoring_cidr is not None:
            self.interface_monitoring_cidr = interface_monitoring_cidr
        if interface_kvm_gateway_ipv4 is not None:
            self.interface_kvm_gateway_ipv4 = interface_kvm_gateway_ipv4
        if interface_additional_routes_cidrs is not None:
            self.interface_additional_routes_cidrs = interface_additional_routes_cidrs

    @property
    def interface_name(self):
        """Gets the interface_name of this TsoaPartialInterfaceObject_.  # noqa: E501


        :return: The interface_name of this TsoaPartialInterfaceObject_.  # noqa: E501
        :rtype: str
        """
        return self._interface_name

    @interface_name.setter
    def interface_name(self, interface_name):
        """Sets the interface_name of this TsoaPartialInterfaceObject_.


        :param interface_name: The interface_name of this TsoaPartialInterfaceObject_.  # noqa: E501
        :type: str
        """

        self._interface_name = interface_name

    @property
    def interface_type(self):
        """Gets the interface_type of this TsoaPartialInterfaceObject_.  # noqa: E501


        :return: The interface_type of this TsoaPartialInterfaceObject_.  # noqa: E501
        :rtype: InterfaceType
        """
        return self._interface_type

    @interface_type.setter
    def interface_type(self, interface_type):
        """Sets the interface_type of this TsoaPartialInterfaceObject_.


        :param interface_type: The interface_type of this TsoaPartialInterfaceObject_.  # noqa: E501
        :type: InterfaceType
        """

        self._interface_type = interface_type

    @property
    def server_id(self):
        """Gets the server_id of this TsoaPartialInterfaceObject_.  # noqa: E501


        :return: The server_id of this TsoaPartialInterfaceObject_.  # noqa: E501
        :rtype: float
        """
        return self._server_id

    @server_id.setter
    def server_id(self, server_id):
        """Sets the server_id of this TsoaPartialInterfaceObject_.


        :param server_id: The server_id of this TsoaPartialInterfaceObject_.  # noqa: E501
        :type: float
        """

        self._server_id = server_id

    @property
    def server_cidr_ipv4(self):
        """Gets the server_cidr_ipv4 of this TsoaPartialInterfaceObject_.  # noqa: E501


        :return: The server_cidr_ipv4 of this TsoaPartialInterfaceObject_.  # noqa: E501
        :rtype: str
        """
        return self._server_cidr_ipv4

    @server_cidr_ipv4.setter
    def server_cidr_ipv4(self, server_cidr_ipv4):
        """Sets the server_cidr_ipv4 of this TsoaPartialInterfaceObject_.


        :param server_cidr_ipv4: The server_cidr_ipv4 of this TsoaPartialInterfaceObject_.  # noqa: E501
        :type: str
        """

        self._server_cidr_ipv4 = server_cidr_ipv4

    @property
    def server_cidr_ipv6(self):
        """Gets the server_cidr_ipv6 of this TsoaPartialInterfaceObject_.  # noqa: E501


        :return: The server_cidr_ipv6 of this TsoaPartialInterfaceObject_.  # noqa: E501
        :rtype: str
        """
        return self._server_cidr_ipv6

    @server_cidr_ipv6.setter
    def server_cidr_ipv6(self, server_cidr_ipv6):
        """Sets the server_cidr_ipv6 of this TsoaPartialInterfaceObject_.


        :param server_cidr_ipv6: The server_cidr_ipv6 of this TsoaPartialInterfaceObject_.  # noqa: E501
        :type: str
        """

        self._server_cidr_ipv6 = server_cidr_ipv6

    @property
    def interface_monitoring_cidr(self):
        """Gets the interface_monitoring_cidr of this TsoaPartialInterfaceObject_.  # noqa: E501


        :return: The interface_monitoring_cidr of this TsoaPartialInterfaceObject_.  # noqa: E501
        :rtype: str
        """
        return self._interface_monitoring_cidr

    @interface_monitoring_cidr.setter
    def interface_monitoring_cidr(self, interface_monitoring_cidr):
        """Sets the interface_monitoring_cidr of this TsoaPartialInterfaceObject_.


        :param interface_monitoring_cidr: The interface_monitoring_cidr of this TsoaPartialInterfaceObject_.  # noqa: E501
        :type: str
        """

        self._interface_monitoring_cidr = interface_monitoring_cidr

    @property
    def interface_kvm_gateway_ipv4(self):
        """Gets the interface_kvm_gateway_ipv4 of this TsoaPartialInterfaceObject_.  # noqa: E501


        :return: The interface_kvm_gateway_ipv4 of this TsoaPartialInterfaceObject_.  # noqa: E501
        :rtype: str
        """
        return self._interface_kvm_gateway_ipv4

    @interface_kvm_gateway_ipv4.setter
    def interface_kvm_gateway_ipv4(self, interface_kvm_gateway_ipv4):
        """Sets the interface_kvm_gateway_ipv4 of this TsoaPartialInterfaceObject_.


        :param interface_kvm_gateway_ipv4: The interface_kvm_gateway_ipv4 of this TsoaPartialInterfaceObject_.  # noqa: E501
        :type: str
        """

        self._interface_kvm_gateway_ipv4 = interface_kvm_gateway_ipv4

    @property
    def interface_additional_routes_cidrs(self):
        """Gets the interface_additional_routes_cidrs of this TsoaPartialInterfaceObject_.  # noqa: E501


        :return: The interface_additional_routes_cidrs of this TsoaPartialInterfaceObject_.  # noqa: E501
        :rtype: str
        """
        return self._interface_additional_routes_cidrs

    @interface_additional_routes_cidrs.setter
    def interface_additional_routes_cidrs(self, interface_additional_routes_cidrs):
        """Sets the interface_additional_routes_cidrs of this TsoaPartialInterfaceObject_.


        :param interface_additional_routes_cidrs: The interface_additional_routes_cidrs of this TsoaPartialInterfaceObject_.  # noqa: E501
        :type: str
        """

        self._interface_additional_routes_cidrs = interface_additional_routes_cidrs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(TsoaPartialInterfaceObject_, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TsoaPartialInterfaceObject_):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TsoaPartialContentObject_(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "content_title": "str",
        "content_key": "str",
        "content_body": "str",
        "lang_id": "float",
        "content_type": "ContextType",
        "content_visibility": "VisibilityType",
    }

    attribute_map = {
        "content_title": "content_title",
        "content_key": "content_key",
        "content_body": "content_body",
        "lang_id": "lang_id",
        "content_type": "content_type",
        "content_visibility": "content_visibility",
    }

    def __init__(
        self,
        content_title=None,
        content_key=None,
        content_body=None,
        lang_id=None,
        content_type=None,
        content_visibility=None,
    ):  # noqa: E501
        """TsoaPartialContentObject_ - a model defined in Swagger"""  # noqa: E501
        self._content_title = None
        self._content_key = None
        self._content_body = None
        self._lang_id = None
        self._content_type = None
        self._content_visibility = None
        self.discriminator = None
        if content_title is not None:
            self.content_title = content_title
        if content_key is not None:
            self.content_key = content_key
        if content_body is not None:
            self.content_body = content_body
        if lang_id is not None:
            self.lang_id = lang_id
        if content_type is not None:
            self.content_type = content_type
        if content_visibility is not None:
            self.content_visibility = content_visibility

    @property
    def content_title(self):
        """Gets the content_title of this TsoaPartialContentObject_.  # noqa: E501


        :return: The content_title of this TsoaPartialContentObject_.  # noqa: E501
        :rtype: str
        """
        return self._content_title

    @content_title.setter
    def content_title(self, content_title):
        """Sets the content_title of this TsoaPartialContentObject_.


        :param content_title: The content_title of this TsoaPartialContentObject_.  # noqa: E501
        :type: str
        """

        self._content_title = content_title

    @property
    def content_key(self):
        """Gets the content_key of this TsoaPartialContentObject_.  # noqa: E501


        :return: The content_key of this TsoaPartialContentObject_.  # noqa: E501
        :rtype: str
        """
        return self._content_key

    @content_key.setter
    def content_key(self, content_key):
        """Sets the content_key of this TsoaPartialContentObject_.


        :param content_key: The content_key of this TsoaPartialContentObject_.  # noqa: E501
        :type: str
        """

        self._content_key = content_key

    @property
    def content_body(self):
        """Gets the content_body of this TsoaPartialContentObject_.  # noqa: E501


        :return: The content_body of this TsoaPartialContentObject_.  # noqa: E501
        :rtype: str
        """
        return self._content_body

    @content_body.setter
    def content_body(self, content_body):
        """Sets the content_body of this TsoaPartialContentObject_.


        :param content_body: The content_body of this TsoaPartialContentObject_.  # noqa: E501
        :type: str
        """

        self._content_body = content_body

    @property
    def lang_id(self):
        """Gets the lang_id of this TsoaPartialContentObject_.  # noqa: E501


        :return: The lang_id of this TsoaPartialContentObject_.  # noqa: E501
        :rtype: float
        """
        return self._lang_id

    @lang_id.setter
    def lang_id(self, lang_id):
        """Sets the lang_id of this TsoaPartialContentObject_.


        :param lang_id: The lang_id of this TsoaPartialContentObject_.  # noqa: E501
        :type: float
        """

        self._lang_id = lang_id

    @property
    def content_type(self):
        """Gets the content_type of this TsoaPartialContentObject_.  # noqa: E501


        :return: The content_type of this TsoaPartialContentObject_.  # noqa: E501
        :rtype: ContextType
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """Sets the content_type of this TsoaPartialContentObject_.


        :param content_type: The content_type of this TsoaPartialContentObject_.  # noqa: E501
        :type: ContextType
        """

        self._content_type = content_type

    @property
    def content_visibility(self):
        """Gets the content_visibility of this TsoaPartialContentObject_.  # noqa: E501


        :return: The content_visibility of this TsoaPartialContentObject_.  # noqa: E501
        :rtype: VisibilityType
        """
        return self._content_visibility

    @content_visibility.setter
    def content_visibility(self, content_visibility):
        """Sets the content_visibility of this TsoaPartialContentObject_.


        :param content_visibility: The content_visibility of this TsoaPartialContentObject_.  # noqa: E501
        :type: VisibilityType
        """

        self._content_visibility = content_visibility

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(TsoaPartialContentObject_, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TsoaPartialContentObject_):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TsoaPartialLanguageObject_(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "lang_code": "str",
        "lang_title": "str",
        "lang_native_title": "str",
        "lang_weight": "float",
        "lang_visibility": "VisibilityType",
    }

    attribute_map = {
        "lang_code": "lang_code",
        "lang_title": "lang_title",
        "lang_native_title": "lang_native_title",
        "lang_weight": "lang_weight",
        "lang_visibility": "lang_visibility",
    }

    def __init__(
        self,
        lang_code=None,
        lang_title=None,
        lang_native_title=None,
        lang_weight=None,
        lang_visibility=None,
    ):  # noqa: E501
        """TsoaPartialLanguageObject_ - a model defined in Swagger"""  # noqa: E501
        self._lang_code = None
        self._lang_title = None
        self._lang_native_title = None
        self._lang_weight = None
        self._lang_visibility = None
        self.discriminator = None
        if lang_code is not None:
            self.lang_code = lang_code
        if lang_title is not None:
            self.lang_title = lang_title
        if lang_native_title is not None:
            self.lang_native_title = lang_native_title
        if lang_weight is not None:
            self.lang_weight = lang_weight
        if lang_visibility is not None:
            self.lang_visibility = lang_visibility

    @property
    def lang_code(self):
        """Gets the lang_code of this TsoaPartialLanguageObject_.  # noqa: E501


        :return: The lang_code of this TsoaPartialLanguageObject_.  # noqa: E501
        :rtype: str
        """
        return self._lang_code

    @lang_code.setter
    def lang_code(self, lang_code):
        """Sets the lang_code of this TsoaPartialLanguageObject_.


        :param lang_code: The lang_code of this TsoaPartialLanguageObject_.  # noqa: E501
        :type: str
        """

        self._lang_code = lang_code

    @property
    def lang_title(self):
        """Gets the lang_title of this TsoaPartialLanguageObject_.  # noqa: E501


        :return: The lang_title of this TsoaPartialLanguageObject_.  # noqa: E501
        :rtype: str
        """
        return self._lang_title

    @lang_title.setter
    def lang_title(self, lang_title):
        """Sets the lang_title of this TsoaPartialLanguageObject_.


        :param lang_title: The lang_title of this TsoaPartialLanguageObject_.  # noqa: E501
        :type: str
        """

        self._lang_title = lang_title

    @property
    def lang_native_title(self):
        """Gets the lang_native_title of this TsoaPartialLanguageObject_.  # noqa: E501


        :return: The lang_native_title of this TsoaPartialLanguageObject_.  # noqa: E501
        :rtype: str
        """
        return self._lang_native_title

    @lang_native_title.setter
    def lang_native_title(self, lang_native_title):
        """Sets the lang_native_title of this TsoaPartialLanguageObject_.


        :param lang_native_title: The lang_native_title of this TsoaPartialLanguageObject_.  # noqa: E501
        :type: str
        """

        self._lang_native_title = lang_native_title

    @property
    def lang_weight(self):
        """Gets the lang_weight of this TsoaPartialLanguageObject_.  # noqa: E501


        :return: The lang_weight of this TsoaPartialLanguageObject_.  # noqa: E501
        :rtype: float
        """
        return self._lang_weight

    @lang_weight.setter
    def lang_weight(self, lang_weight):
        """Sets the lang_weight of this TsoaPartialLanguageObject_.


        :param lang_weight: The lang_weight of this TsoaPartialLanguageObject_.  # noqa: E501
        :type: float
        """

        self._lang_weight = lang_weight

    @property
    def lang_visibility(self):
        """Gets the lang_visibility of this TsoaPartialLanguageObject_.  # noqa: E501


        :return: The lang_visibility of this TsoaPartialLanguageObject_.  # noqa: E501
        :rtype: VisibilityType
        """
        return self._lang_visibility

    @lang_visibility.setter
    def lang_visibility(self, lang_visibility):
        """Sets the lang_visibility of this TsoaPartialLanguageObject_.


        :param lang_visibility: The lang_visibility of this TsoaPartialLanguageObject_.  # noqa: E501
        :type: VisibilityType
        """

        self._lang_visibility = lang_visibility

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(TsoaPartialLanguageObject_, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TsoaPartialLanguageObject_):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from syntropy_sdk.api.api_keys_api import ApiKeysApi
from syntropy_sdk.api.auth_api import AuthApi
from syntropy_sdk.api.platform_api import PlatformApi

# import ApiClient
from syntropy_sdk.api_client import ApiClient
from syntropy_sdk.configuration import Configuration

# import models into sdk package
from syntropy_sdk.models.admin_agent_config import AdminAgentConfig
from syntropy_sdk.models.agent_connection_object import AgentConnectionObject
from syntropy_sdk.models.agent_connection_response_connection_performance_array_array_ import (
    AgentConnectionResponseConnectionPerformanceArrayArray_,
)
from syntropy_sdk.models.agent_connection_status import AgentConnectionStatus
from syntropy_sdk.models.agent_connection_subnets_deletion_object import (
    AgentConnectionSubnetsDeletionObject,
)
from syntropy_sdk.models.agent_coordinates_object import AgentCoordinatesObject
from syntropy_sdk.models.agent_filters_object import AgentFiltersObject
from syntropy_sdk.models.agent_group_object import AgentGroupObject
from syntropy_sdk.models.agent_interface_bw_object import AgentInterfaceBwObject
from syntropy_sdk.models.agent_interface_metadata import AgentInterfaceMetadata
from syntropy_sdk.models.agent_interface_object import AgentInterfaceObject
from syntropy_sdk.models.agent_interfaces_metadata import AgentInterfacesMetadata
from syntropy_sdk.models.agent_locked_fields import AgentLockedFields
from syntropy_sdk.models.agent_message_payload import AgentMessagePayload
from syntropy_sdk.models.agent_message_type import AgentMessageType
from syntropy_sdk.models.agent_network_object import AgentNetworkObject
from syntropy_sdk.models.agent_object import AgentObject
from syntropy_sdk.models.agent_path_object import AgentPathObject
from syntropy_sdk.models.agent_provider_object import AgentProviderObject
from syntropy_sdk.models.agent_provider_order_string import AgentProviderOrderString
from syntropy_sdk.models.agent_service_object import AgentServiceObject
from syntropy_sdk.models.agent_service_types import AgentServiceTypes
from syntropy_sdk.models.agent_services_deletion_object import (
    AgentServicesDeletionObject,
)
from syntropy_sdk.models.agent_services_update_changes_object import (
    AgentServicesUpdateChangesObject,
)
from syntropy_sdk.models.agent_services_update_object import AgentServicesUpdateObject
from syntropy_sdk.models.agent_success_response import AgentSuccessResponse
from syntropy_sdk.models.agent_tag_object import AgentTagObject
from syntropy_sdk.models.agent_version import AgentVersion
from syntropy_sdk.models.agents_object import AgentsObject
from syntropy_sdk.models.agents_pair_object import AgentsPairObject
from syntropy_sdk.models.any_of_agent_message_payload import AnyOfAgentMessagePayload
from syntropy_sdk.models.any_of_platform_response_error_item_value import (
    AnyOfPlatformResponseErrorItemValue,
)
from syntropy_sdk.models.any_of_vpp_callable_object import AnyOfVppCallableObject
from syntropy_sdk.models.any_of_wg_callable_object import AnyOfWgCallableObject
from syntropy_sdk.models.any_ofinline_response204 import AnyOfinlineResponse204
from syntropy_sdk.models.api_key_object import ApiKeyObject
from syntropy_sdk.models.auto_ping_payload import AutoPingPayload
from syntropy_sdk.models.behavior_type import BehaviorType
from syntropy_sdk.models.bi_statistics import BiStatistics
from syntropy_sdk.models.bi_statistics_edges_post import BiStatisticsEdgesPost
from syntropy_sdk.models.body import Body
from syntropy_sdk.models.body1 import Body1
from syntropy_sdk.models.body2 import Body2
from syntropy_sdk.models.body3 import Body3
from syntropy_sdk.models.body4 import Body4
from syntropy_sdk.models.body5 import Body5
from syntropy_sdk.models.change_path_object import ChangePathObject
from syntropy_sdk.models.change_path_object_data import ChangePathObjectData
from syntropy_sdk.models.change_path_object_data_costs import ChangePathObjectDataCosts
from syntropy_sdk.models.color_object import ColorObject
from syntropy_sdk.models.connection_creation_body import ConnectionCreationBody
from syntropy_sdk.models.connection_creation_body_mesh import ConnectionCreationBodyMesh
from syntropy_sdk.models.connection_creation_body_p2p import ConnectionCreationBodyP2p
from syntropy_sdk.models.connection_performance import ConnectionPerformance
from syntropy_sdk.models.constraint_enum import ConstraintEnum
from syntropy_sdk.models.content_object import ContentObject
from syntropy_sdk.models.context_type import ContextType
from syntropy_sdk.models.default_string import DefaultString
from syntropy_sdk.models.id_number import IdNumber
from syntropy_sdk.models.inline_response204 import InlineResponse204
from syntropy_sdk.models.interface_object import InterfaceObject
from syntropy_sdk.models.interface_type import InterfaceType
from syntropy_sdk.models.ipv4 import Ipv4
from syntropy_sdk.models.language_object import LanguageObject
from syntropy_sdk.models.latitude import Latitude
from syntropy_sdk.models.link_object import LinkObject
from syntropy_sdk.models.link_tag import LinkTag
from syntropy_sdk.models.logs_read_timestamp_entity_types import (
    LogsReadTimestampEntityTypes,
)
from syntropy_sdk.models.logs_read_timestamp_object import LogsReadTimestampObject
from syntropy_sdk.models.longitude import Longitude
from syntropy_sdk.models.metadata_network_type import MetadataNetworkType
from syntropy_sdk.models.network_agent_object import NetworkAgentObject
from syntropy_sdk.models.network_agent_payload import NetworkAgentPayload
from syntropy_sdk.models.network_genesis_type import NetworkGenesisType
from syntropy_sdk.models.network_info_object import NetworkInfoObject
from syntropy_sdk.models.network_metadata import NetworkMetadata
from syntropy_sdk.models.network_object import NetworkObject
from syntropy_sdk.models.network_topology_object import NetworkTopologyObject
from syntropy_sdk.models.order_string import OrderString
from syntropy_sdk.models.platform_agent_status import PlatformAgentStatus
from syntropy_sdk.models.platform_agent_type_local import PlatformAgentTypeLocal
from syntropy_sdk.models.platform_agents_body_object import PlatformAgentsBodyObject
from syntropy_sdk.models.platform_agents_error_body import PlatformAgentsErrorBody
from syntropy_sdk.models.platform_agents_error_response import (
    PlatformAgentsErrorResponse,
)
from syntropy_sdk.models.platform_agents_error_response_hits import (
    PlatformAgentsErrorResponseHits,
)
from syntropy_sdk.models.platform_agents_hit_object import PlatformAgentsHitObject
from syntropy_sdk.models.platform_agents_hit_object_source import (
    PlatformAgentsHitObjectSource,
)
from syntropy_sdk.models.platform_response5_b_link_tag_public5_d3_f3_astring5_b_link_tag_sdn15_d3_f3_astring5_b_link_tag_sdn25_d3_f3_astring5_b_link_tag_sdn35_d3_f3_astring_ import (
    PlatformResponse5BLinkTagPublic5D3F3Astring5BLinkTagSdn15D3F3Astring5BLinkTagSdn25D3F3Astring5BLinkTagSdn35D3F3Astring_,
)
from syntropy_sdk.models.platform_response5_b_link_tag_public5_d3_f3_astring5_b_link_tag_sdn15_d3_f3_astring5_b_link_tag_sdn25_d3_f3_astring5_b_link_tag_sdn35_d3_f3_astring_data import (
    PlatformResponse5BLinkTagPublic5D3F3Astring5BLinkTagSdn15D3F3Astring5BLinkTagSdn25D3F3Astring5BLinkTagSdn35D3F3AstringData,
)
from syntropy_sdk.models.platform_response_admin_agent_config_ import (
    PlatformResponseAdminAgentConfig_,
)
from syntropy_sdk.models.platform_response_agent_connection_object_array_ import (
    PlatformResponseAgentConnectionObjectArray_,
)
from syntropy_sdk.models.platform_response_agent_coordinates_object_array_ import (
    PlatformResponseAgentCoordinatesObjectArray_,
)
from syntropy_sdk.models.platform_response_agent_filters_object_ import (
    PlatformResponseAgentFiltersObject_,
)
from syntropy_sdk.models.platform_response_agent_object_ import (
    PlatformResponseAgentObject_,
)
from syntropy_sdk.models.platform_response_agent_object_array_ import (
    PlatformResponseAgentObjectArray_,
)
from syntropy_sdk.models.platform_response_agent_provider_object_ import (
    PlatformResponseAgentProviderObject_,
)
from syntropy_sdk.models.platform_response_agent_provider_object_array_ import (
    PlatformResponseAgentProviderObjectArray_,
)
from syntropy_sdk.models.platform_response_agent_service_object_array_ import (
    PlatformResponseAgentServiceObjectArray_,
)
from syntropy_sdk.models.platform_response_agent_success_response_ import (
    PlatformResponseAgentSuccessResponse_,
)
from syntropy_sdk.models.platform_response_agent_tag_object_array_ import (
    PlatformResponseAgentTagObjectArray_,
)
from syntropy_sdk.models.platform_response_api_key_object_ import (
    PlatformResponseApiKeyObject_,
)
from syntropy_sdk.models.platform_response_api_key_object_array_ import (
    PlatformResponseApiKeyObjectArray_,
)
from syntropy_sdk.models.platform_response_error_item import PlatformResponseErrorItem
from syntropy_sdk.models.platform_response_network_info_object_ import (
    PlatformResponseNetworkInfoObject_,
)
from syntropy_sdk.models.platform_response_network_object_ import (
    PlatformResponseNetworkObject_,
)
from syntropy_sdk.models.platform_response_network_object_array_ import (
    PlatformResponseNetworkObjectArray_,
)
from syntropy_sdk.models.platform_response_network_topology_object_array_ import (
    PlatformResponseNetworkTopologyObjectArray_,
)
from syntropy_sdk.models.platform_response_success_boolean_ import (
    PlatformResponseSuccessBoolean_,
)
from syntropy_sdk.models.platform_response_successboolean_data import (
    PlatformResponseSuccessbooleanData,
)
from syntropy_sdk.models.platform_response_void_ import PlatformResponseVoid_
from syntropy_sdk.models.port import Port
from syntropy_sdk.models.provider_object import ProviderObject
from syntropy_sdk.models.public_app_info_object import PublicAppInfoObject
from syntropy_sdk.models.public_language_object import PublicLanguageObject
from syntropy_sdk.models.public_languages_object import PublicLanguagesObject
from syntropy_sdk.models.public_link_object import PublicLinkObject
from syntropy_sdk.models.public_links_lang_code_object import PublicLinksLangCodeObject
from syntropy_sdk.models.public_links_object import PublicLinksObject
from syntropy_sdk.models.public_translation_object import PublicTranslationObject
from syntropy_sdk.models.public_translations_lang_code_object import (
    PublicTranslationsLangCodeObject,
)
from syntropy_sdk.models.public_translations_object import PublicTranslationsObject
from syntropy_sdk.models.public_versions_object import PublicVersionsObject
from syntropy_sdk.models.region_object import RegionObject
from syntropy_sdk.models.reset_server_object import ResetServerObject
from syntropy_sdk.models.restart_agent_object import RestartAgentObject
from syntropy_sdk.models.route_object import RouteObject
from syntropy_sdk.models.s3_object_list_item import S3ObjectListItem
from syntropy_sdk.models.s3_object_list_item_owner import S3ObjectListItemOwner
from syntropy_sdk.models.s3_send_data import S3SendData
from syntropy_sdk.models.server_agent_status import ServerAgentStatus
from syntropy_sdk.models.server_object import ServerObject
from syntropy_sdk.models.server_sr_software import ServerSrSoftware
from syntropy_sdk.models.setting_read_object import SettingReadObject
from syntropy_sdk.models.setting_write_object import SettingWriteObject
from syntropy_sdk.models.settings_types import SettingsTypes
from syntropy_sdk.models.show_sdn_connections import ShowSdnConnections
from syntropy_sdk.models.skip_number import SkipNumber
from syntropy_sdk.models.sr_path_object import SrPathObject
from syntropy_sdk.models.sr_policy_object import SrPolicyObject
from syntropy_sdk.models.status import Status
from syntropy_sdk.models.take_number import TakeNumber
from syntropy_sdk.models.topology_object import TopologyObject
from syntropy_sdk.models.translation_object import TranslationObject
from syntropy_sdk.models.tsoa_partial_agent_connection_object_ import (
    TsoaPartialAgentConnectionObject_,
)
from syntropy_sdk.models.tsoa_partial_agent_interface_bw_object_ import (
    TsoaPartialAgentInterfaceBwObject_,
)
from syntropy_sdk.models.tsoa_partial_agent_interface_object_ import (
    TsoaPartialAgentInterfaceObject_,
)
from syntropy_sdk.models.tsoa_partial_agent_network_object_ import (
    TsoaPartialAgentNetworkObject_,
)
from syntropy_sdk.models.tsoa_partial_agent_object_ import TsoaPartialAgentObject_
from syntropy_sdk.models.tsoa_partial_agent_path_object_ import (
    TsoaPartialAgentPathObject_,
)
from syntropy_sdk.models.tsoa_partial_agent_provider_object_ import (
    TsoaPartialAgentProviderObject_,
)
from syntropy_sdk.models.tsoa_partial_api_key_object_ import TsoaPartialApiKeyObject_
from syntropy_sdk.models.tsoa_partial_color_object_ import TsoaPartialColorObject_
from syntropy_sdk.models.tsoa_partial_content_object_ import TsoaPartialContentObject_
from syntropy_sdk.models.tsoa_partial_interface_object_ import (
    TsoaPartialInterfaceObject_,
)
from syntropy_sdk.models.tsoa_partial_language_object_ import TsoaPartialLanguageObject_
from syntropy_sdk.models.tsoa_partial_link_object_ import TsoaPartialLinkObject_
from syntropy_sdk.models.tsoa_partial_network_object_ import TsoaPartialNetworkObject_
from syntropy_sdk.models.tsoa_partial_provider_object_ import TsoaPartialProviderObject_
from syntropy_sdk.models.tsoa_partial_region_object_ import TsoaPartialRegionObject_
from syntropy_sdk.models.tsoa_partial_route_object_ import TsoaPartialRouteObject_
from syntropy_sdk.models.tsoa_partial_server_object_ import TsoaPartialServerObject_
from syntropy_sdk.models.tsoa_partial_topology_object_ import TsoaPartialTopologyObject_
from syntropy_sdk.models.tsoa_partial_translation_object_ import (
    TsoaPartialTranslationObject_,
)
from syntropy_sdk.models.tsoa_partial_tunnel_object_ import TsoaPartialTunnelObject_
from syntropy_sdk.models.tsoa_partial_user_sr_object_ import TsoaPartialUserSrObject_
from syntropy_sdk.models.tsoa_partial_version_object_ import TsoaPartialVersionObject_
from syntropy_sdk.models.tsoa_partial_vpn_object_ import TsoaPartialVpnObject_
from syntropy_sdk.models.tsoa_pick_agent_agent_id_or_agent_location_lat_or_agent_location_lon_ import (
    TsoaPickAgentAgentIdOrAgentLocationLatOrAgentLocationLon_,
)
from syntropy_sdk.models.tsoa_pick_agent_agent_location_country_ import (
    TsoaPickAgentAgentLocationCountry_,
)
from syntropy_sdk.models.tsoa_pick_agent_agent_name_or_agent_id_ import (
    TsoaPickAgentAgentNameOrAgentId_,
)
from syntropy_sdk.models.tsoa_pick_agent_agent_version_ import (
    TsoaPickAgentAgentVersion_,
)
from syntropy_sdk.models.tunnel_object import TunnelObject
from syntropy_sdk.models.update_status_body import UpdateStatusBody
from syntropy_sdk.models.update_status_body_subnets_to_update import (
    UpdateStatusBodySubnetsToUpdate,
)
from syntropy_sdk.models.user_admin_object import UserAdminObject
from syntropy_sdk.models.user_agent_create_object import UserAgentCreateObject
from syntropy_sdk.models.user_agent_patch_object import UserAgentPatchObject
from syntropy_sdk.models.user_api_key_create_object import UserApiKeyCreateObject
from syntropy_sdk.models.user_network_object import UserNetworkObject
from syntropy_sdk.models.user_settings import UserSettings
from syntropy_sdk.models.user_sr_direction import UserSrDirection
from syntropy_sdk.models.user_sr_object import UserSrObject
from syntropy_sdk.models.version_object import VersionObject
from syntropy_sdk.models.version_type import VersionType
from syntropy_sdk.models.visibility_type import VisibilityType
from syntropy_sdk.models.vpn_object import VpnObject
from syntropy_sdk.models.vpp_callable_object import VppCallableObject
from syntropy_sdk.models.vpp_callable_object_args import VppCallableObjectArgs
from syntropy_sdk.models.vpp_callable_object_args1 import VppCallableObjectArgs1
from syntropy_sdk.models.vpp_callable_object_args2 import VppCallableObjectArgs2
from syntropy_sdk.models.vpp_callable_object_args3 import VppCallableObjectArgs3
from syntropy_sdk.models.vpp_callable_object_args4 import VppCallableObjectArgs4
from syntropy_sdk.models.vpp_callable_object_args5 import VppCallableObjectArgs5
from syntropy_sdk.models.vpp_callable_object_args6 import VppCallableObjectArgs6
from syntropy_sdk.models.vpp_callable_object_args7 import VppCallableObjectArgs7
from syntropy_sdk.models.vpp_callable_object_args8 import VppCallableObjectArgs8
from syntropy_sdk.models.vpp_callable_object_args9 import VppCallableObjectArgs9
from syntropy_sdk.models.vpp_callable_object_args10 import VppCallableObjectArgs10
from syntropy_sdk.models.vpp_callable_object_args11 import VppCallableObjectArgs11
from syntropy_sdk.models.vpp_callable_object_args12 import VppCallableObjectArgs12
from syntropy_sdk.models.vpp_callable_object_args13 import VppCallableObjectArgs13
from syntropy_sdk.models.vpp_callable_object_args14 import VppCallableObjectArgs14
from syntropy_sdk.models.vpp_callable_object_args15 import VppCallableObjectArgs15
from syntropy_sdk.models.vpp_callable_object_args16 import VppCallableObjectArgs16
from syntropy_sdk.models.wg_add_peer import WgAddPeer
from syntropy_sdk.models.wg_add_peer_args import WgAddPeerArgs
from syntropy_sdk.models.wg_add_peer_metadata import WgAddPeerMetadata
from syntropy_sdk.models.wg_add_peer_metadata_allowed_ips_info import (
    WgAddPeerMetadataAllowedIpsInfo,
)
from syntropy_sdk.models.wg_callable_object import WgCallableObject
from syntropy_sdk.models.wg_create_interface import WgCreateInterface
from syntropy_sdk.models.wg_create_interface_args import WgCreateInterfaceArgs
from syntropy_sdk.models.wg_create_interface_metadata import WgCreateInterfaceMetadata
from syntropy_sdk.models.wg_keypair_object import WgKeypairObject
from syntropy_sdk.models.wg_public_key import WgPublicKey
from syntropy_sdk.models.wg_remove_interface import WgRemoveInterface
from syntropy_sdk.models.wg_remove_interface_args import WgRemoveInterfaceArgs
from syntropy_sdk.models.wg_remove_peer import WgRemovePeer
from syntropy_sdk.models.wg_remove_peer_args import WgRemovePeerArgs
from syntropy_sdk.models.where_string import WhereString
